#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oemedchem
import sys


################################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEMEDCHEM DOCUMENTATION
# - please look at actual examples for useful utility code
################################################################


def SerializeInput(itf):
    ims = oechem.oemolistream()
    if not ims.open(itf.GetString("-input")):
        oechem.OEThrow.Fatal("Unable to open %s for reading:"+itf.GetString("-input"))

    oechem.OEThrow.SetLevel(oechem.OEErrorLevel_Warning)

    # @ <SNIPPET-MATCHEDPAIRANALYZER-EXPORT-COMPRESS-MMP>
    # create analyzer class with defaults
    #   - compression option disabled by default
    mmpAnalyzer = oemedchem.OEMatchedPairAnalyzer()
    # for serialization, enable export compression to
    #   remove singleton index nodes by modifying analyzer
    mmpAnalyzer.ModifyOptions(oemedchem.OEMatchedPairOptions_ExportCompression, 0)
    # @ </SNIPPET-MATCHEDPAIRANALYZER-EXPORT-COMPRESS-MMP>

    # @ <SNIPPET-MATCHEDPAIRANALYZER-EXPORT-COMPRESS-OPTS>
    # create options class with defaults
    #   - compression option disabled by default
    mmpOpts = oemedchem.OEMatchedPairAnalyzerOptions()
    # for serialization, enable export compression to
    #   remove singleton index nodes by modifying analyzer
    mmpOpts.SetOptions(oemedchem.OEMatchedPairOptions_Default |
                       oemedchem.OEMatchedPairOptions_ExportCompression)
    # create analyzer class with compression option enabled
    mmpAnalyzer = oemedchem.OEMatchedPairAnalyzer(mmpOpts)
    # @ </SNIPPET-MATCHEDPAIRANALYZER-EXPORT-COMPRESS-OPTS>

    # @ <SNIPPET-MATCHEDPAIRANALYZER-SERIALIZE-INDEX>
    mmp = oemedchem.OEMatchedPairAnalyzer()
    for recindex, mol in enumerate(ims.GetOEGraphMols()):
        status = mmp.AddMol(mol, recindex)
        if status != recindex:
            oechem.OEThrow.Warning(
                "{0}: molecule indexing error, status={1}"
                .format(recindex, oemedchem.OEMatchedPairIndexStatusName(status)))

    print("Index complete, matched pairs = {0}".format(mmp.NumMatchedPairs()))

    # check for output filename with .mmpidx extension
    mmpexport = itf.GetString("-output")
    if not oemedchem.OEIsMatchedPairAnalyzerFileType(mmpexport):
        oechem.OEThrow.Info('Not a valid matched pair index output file, '+mmpexport)
    elif not oemedchem.OEWriteMatchedPairAnalyzer(mmpexport, mmp):
        oechem.OEThrow.Fatal("Index serialization failed")
    else:
        oechem.OEThrow.Info("Index serialization complete")
    # @ </SNIPPET-MATCHEDPAIRANALYZER-SERIALIZE-INDEX>
    print("Index serialization complete")

    mmpimport = mmpexport
    # now try to reload serialized index
    # @ <SNIPPET-MATCHEDPAIRANALYZER-DESERIALIZE-INDEX>
    mmp = oemedchem.OEMatchedPairAnalyzer()
    if not oemedchem.OEIsMatchedPairAnalyzerFileType(mmpimport):
        oechem.OEThrow.Fatal('Not a valid matched pair index input file, '+mmpimport)
    elif not oemedchem.OEReadMatchedPairAnalyzer(mmpimport, mmp):
        oechem.OEThrow.Fatal("Index deserialization failed")
    else:
        oechem.OEThrow.Info("Index deserialization complete")
    # @ </SNIPPET-MATCHEDPAIRANALYZER-DESERIALIZE-INDEX>
    print("Index deserialization complete")

    return True


############################################################
InterfaceData = """
# SerializeIndex docexample
!CATEGORY SerializeIndex
    !CATEGORY I/O
        !PARAMETER -input 1
          !ALIAS -i
          !TYPE string
          !REQUIRED true
          !BRIEF Input filename of structures to index
          !KEYLESS 1
        !END

        !PARAMETER -output 2
          !ALIAS -o
          !TYPE string
          !REQUIRED true
          !BRIEF Output filename for serialized index
          !KEYLESS 2
        !END
    !END
!END
"""


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData)
    oemedchem.OEConfigureMatchedPairIndexOptions(itf)

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    SerializeInput(itf)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEDEPICT DOCUMENTATION
###############################################################


def CreateReportLayout():

    rows, cols = 3, 2
    reportopts = oedepict.OEReportOptions(rows, cols)
    reportopts.SetPageWidth(100.0)
    reportopts.SetPageHeight(150.0)
    reportopts.SetPageMargins(5.0)
    reportopts.SetCellGap(5.0)
    reportopts.SetHeaderHeight(15.0)
    reportopts.SetFooterHeight(15.0)
    report = oedepict.OEReport(reportopts)

    borderpen = oedepict.OEPen(oechem.OELightGrey, oechem.OELightGrey, oedepict.OEFill_Off, 1.0)

    first = report.NewBody()
    oedepict.OEDrawBorder(first, borderpen)

    nrgridpages = 3
    for p in range(0, nrgridpages):
        for c in range(0, report.NumRowsPerPage() * report.NumColsPerPage()):
            cell = report.NewCell()
            oedepict.OEDrawBorder(cell, borderpen)

    last = report.NewBody()
    oedepict.OEDrawBorder(last, borderpen)

    for page in report.GetPages():
        oedepict.OEDrawBorder(page, oedepict.OEBlackPen)
    for header in report.GetHeaders():
        oedepict.OEDrawBorder(header, borderpen)
    for footer in report.GetFooters():
        oedepict.OEDrawBorder(footer, borderpen)

    return report


def HighlightCell(cell, idx):

    font = oedepict.OEFont(oedepict.OEFontFamily_Default, oedepict.OEFontStyle_Default, 10,
                           oedepict.OEAlignment_Center, oechem.OEBlack)
    color = oechem.OEColor(oechem.OELightGrey)
    borderpen = oedepict.OEPen(color, color, oedepict.OEFill_On, 1.0)

    oedepict.OEDrawBorder(cell, borderpen)
    p = oedepict.OE2DPoint(cell.GetWidth() / 2.0, cell.GetHeight() / 2.0 + font.GetSize() / 2.0)
    cell.DrawText(p, "(%d)" % idx, font)


def WriteReportPageByPage(report, filenamebase):

    for pidx in range(1, report.NumPages() + 1):
        oedepict.OEWriteReport("%s-%d.pdf" % (filenamebase, pidx), report, pidx)
        oedepict.OEWriteReport("%s-%d.png" % (filenamebase, pidx), report, pidx)


report = CreateReportLayout()
idx = 1
# @ <SNIPPET-OEREPORT-GETCELLS-ALL>
for cell in report.GetCells():
    pass
# @ </SNIPPET-OEREPORT-GETCELLS-ALL>
    HighlightCell(cell, idx)
    idx += 1
WriteReportPageByPage(report, "OEReportIter-cells-all")


report = CreateReportLayout()
idx = 1
# @ <SNIPPET-OEREPORT-GETCELLS-ALLPAGES-ROW-ALLCOLS>
row = 2
for cell in report.GetCells(0, row, 0):
    pass
# @ </SNIPPET-OEREPORT-GETCELLS-ALLPAGES-ROW-ALLCOLS>
    HighlightCell(cell, idx)
    idx += 1
WriteReportPageByPage(report, "OEReportIter-cells-allpages-row-allcols")


report = CreateReportLayout()
idx = 1
# @ <SNIPPET-OEREPORT-GETCELLS-ALLPAGES-ALLROWS-COL>
col = 2
for cell in report.GetCells(0, 0, col):
    pass
# @ </SNIPPET-OEREPORT-GETCELLS-ALLPAGES-ALLROWS-COL>
    HighlightCell(cell, idx)
    idx += 1
WriteReportPageByPage(report, "OEReportIter-cells-allpages-allrows-col")


report = CreateReportLayout()
idx = 1
# @ <SNIPPET-OEREPORT-GETCELLS-ALLPAGES-ROW-COL>
row = 2
col = 2
for cell in report.GetCells(0, row, col):
    pass
# @ </SNIPPET-OEREPORT-GETCELLS-ALLPAGES-ROW-COL>
    HighlightCell(cell, idx)
    idx += 1
WriteReportPageByPage(report, "OEReportIter-cells-allpages-row-col")


report = CreateReportLayout()
idx = 1
# @ <SNIPPET-OEREPORT-GETCELLS-PAGE-ROW-ALLCOLS>
page = 3
row = 2
for cell in report.GetCells(page, row, 0):
    pass
# @ </SNIPPET-OEREPORT-GETCELLS-PAGE-ROW-ALLCOLS>
    HighlightCell(cell, idx)
    idx += 1
WriteReportPageByPage(report, "OEReportIter-cells-page-row-allcols")


report = CreateReportLayout()
idx = 1
# @ <SNIPPET-OEREPORT-GETCELLS-PAGE-ALLROWS-COL>
page = 3
col = 2
for cell in report.GetCells(page, 0, col):
    pass
# @ </SNIPPET-OEREPORT-GETCELLS-PAGE-ALLROWS-COL>
    HighlightCell(cell, idx)
    idx += 1
WriteReportPageByPage(report, "OEReportIter-cells-page-allrows-col")


report = CreateReportLayout()
idx = 1
# @ <SNIPPET-OEREPORT-GETCELLS-PAGE-ROW-COL>
page = 3
row = 2
col = 2
for cell in report.GetCells(page, row, col):
    pass
# @ </SNIPPET-OEREPORT-GETCELLS-PAGE-ROW-COL>
    HighlightCell(cell, idx)
    idx += 1
WriteReportPageByPage(report, "OEReportIter-cells-page-row-col")


report = CreateReportLayout()
idx = 1
# @ <SNIPPET-OEREPORT-GETHEADERS>
for header in report.GetHeaders():
    pass
# @ </SNIPPET-OEREPORT-GETHEADERS>
    HighlightCell(header, idx)
    idx += 1
WriteReportPageByPage(report, "OEReportIter-headers")


report = CreateReportLayout()
idx = 1
# @ <SNIPPET-OEREPORT-GETFOOTERS>
for footer in report.GetFooters():
    pass
# @ </SNIPPET-OEREPORT-GETFOOTERS>
    HighlightCell(footer, idx)
    idx += 1
WriteReportPageByPage(report, "OEReportIter-footers")


report = CreateReportLayout()
idx = 1
# @ <SNIPPET-OEREPORT-GETBODIES>
for body in report.GetBodies():
    pass
# @ </SNIPPET-OEREPORT-GETBODIES>
    HighlightCell(body, idx)
    idx += 1
WriteReportPageByPage(report, "OEReportIter-bodies")

report = CreateReportLayout()
WriteReportPageByPage(report, "OEReportIter-pages")



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oeszybki

def main(argv=[__name__]):
    torOpts = oeszybki.OETorsionScanOptions()
    opts = oechem.OESimpleAppOptions(torOpts, "TorsionScan",oechem.OEFileStringType_Mol3D,
                                     oechem.OEFileStringType_Mol3D)

    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0
    torOpts.UpdateValues(opts)

    ifs = oechem.oemolistream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    mol = oechem.OEMol()
    oechem.OEReadMolecule(ifs, mol)

    outmol = oechem.OEMol()

    for tor in oechem.OEGetTorsions(mol):
        print("Torsion: %d %d %d %d" %
              (tor.a.GetIdx(), tor.b.GetIdx(), tor.c.GetIdx(), tor.d.GetIdx()))
        for res in oeszybki.OETorsionScan(outmol, mol, tor, torOpts):
            print("%.2f %.2f" % (res.GetAngle(), res.GetEnergy()))

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

# @ <SNIPPET-DEPICT-MOL-WITH-HYPERLINK>
mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "OC(=O)c1ccccc1")
oedepict.OEPrepareDepiction(mol)

width, height = 150.0, 150.0
image = oedepict.OEImage(width, height)
opts = oedepict.OE2DMolDisplayOptions(width, height, oedepict.OEScale_AutoScale)
opts.SetTitleLocation(oedepict.OETitleLocation_Bottom)

# associate font with URI

font = oedepict.OEFont(oedepict.OEFontFamily_Default, oedepict.OEFontStyle_Default, 10,
                       oedepict.OEAlignment_Center, oechem.OEBlue)
font.SetHyperlink("http://www.eyesopen.com/oedepict-tk")

opts.SetTitleFont(font)
mol.SetTitle("Generated by OEDepict")

disp = oedepict.OE2DMolDisplay(mol, opts)
oedepict.OERenderMolecule(image, disp)

oedepict.OEWriteImage("DepictMolWithHyperlink.pdf", image)
oedepict.OEWriteImage("DepictMolWithHyperlink.svg", image)
# @ </SNIPPET-DEPICT-MOL-WITH-HYPERLINK>



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem
from openeye import oeszybki


def main(argv=[__name__]):
    itf = oechem.OEInterface(Interface, argv)

    lfs = oechem.oemolistream()
    if not lfs.open(itf.GetString("-in")):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % itf.GetString("-in"))

    pfs = oechem.oemolistream()
    if not pfs.open(itf.GetString("-p")):
        oechem.OEThrow.Fatal("Unable to open %s for reading", itf.GetString("-p"))

    olfs = oechem.oemolostream()
    if not olfs.open(itf.GetString("-out")):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % itf.GetString("-out"))

    opfs = oechem.oemolostream()
    if itf.HasString("-s"):
        if not opfs.open(itf.GetString("-s")):
            oechem.OEThrow.Fatal("Unable to open %s for writing" % itf.GetString("-s"))

    logfile = oechem.oeout
    if itf.HasString("-log"):
        if not logfile.open(itf.GetString("-log")):
            oechem.OEThrow.Fatal("Unable to open %s for writing" % itf.GetString("-log"))

    # Szybki options
    opts = oeszybki.OESzybkiOptions()

    # select optimization type
    opt = itf.GetString("-opt")
    if opt == "Cartesian":
        opts.SetRunType(oeszybki.OERunType_CartesiansOpt)
    if opt == "Torsion":
        opts.SetRunType(oeszybki.OERunType_TorsionsOpt)
    if opt == "SolidBody":
        opts.SetRunType(oeszybki.OERunType_SolidBodyOpt)

    # select protein-electrostatic model
    emodel = itf.GetString("-e")
    elecModel = oeszybki.OEProteinElectrostatics_NoElectrostatics
    if emodel == "VdW":
        elecModel = oeszybki.OEProteinElectrostatics_NoElectrostatics
    elif emodel == "PB":
        elecModel = oeszybki.OEProteinElectrostatics_GridPB
    elif emodel == "Coulomb":
        elecModel = oeszybki.OEProteinElectrostatics_GridCoulomb
    elif emodel == "ExactCoulomb":
        elecModel = oeszybki.OEProteinElectrostatics_ExactCoulomb
    opts.GetProteinOptions().SetProteinElectrostaticModel(elecModel)

    # use smooth potential and tight convergence
    if (emodel == "VdW" or emodel == "ExactCoulomb"):
        opts.GetProteinOptions().SetExactVdWProteinLigand(True)
        opts.GetOptOptions().SetMaxIter(1000)
        opts.GetOptOptions().SetGradTolerance(1e-6)

    # protein flexibility
    opts.GetProteinOptions().SetProteinFlexibilityType(oeszybki.OEProtFlex_SideChains)
    opts.GetProteinOptions().SetProteinFlexibilityRange(itf.GetDouble("-d"))

    # Szybki object
    sz = oeszybki.OESzybki(opts)

    # read and setup protein
    protein = oechem.OEGraphMol()
    oprotein = oechem.OEGraphMol()  # optimized protein
    oechem.OEReadMolecule(pfs, protein)
    sz.SetProtein(protein)

    # process molecules
    for mol in lfs.GetOEMols():
        logfile.write("\nMolecule %s\n" % mol.GetTitle())
        for res in sz(mol):
            res.Print(logfile)

        oechem.OEWriteMolecule(olfs, mol)
        if itf.HasString("-s"):
            sz.GetProtein(oprotein)
            oechem.OEWriteMolecule(opfs, oprotein)

    return 0


Interface = """
!BRIEF -in input_molecule -p protein -out output_molecule
!PARAMETER -in
  !TYPE string
  !REQUIRED true
  !BRIEF Input molecule file name.
!END

!PARAMETER -p
  !TYPE string
  !REQUIRED true
  !BRIEF Input protein file name.
!END

!PARAMETER -out
  !TYPE string
  !REQUIRED true
  !BRIEF Output molecule file name.
!END

!PARAMETER -log
  !TYPE string
  !REQUIRED false
  !BRIEF Log file name. Defaults to standard out.
!END

!PARAMETER -e
  !TYPE string
  !DEFAULT VdW
  !LEGAL_VALUE VdW
  !LEGAL_VALUE PB
  !LEGAL_VALUE Coulomb
  !LEGAL_VALUE ExactCoulomb
  !BRIEF Protein ligand electrostatic model.
!END

!PARAMETER -opt
  !TYPE string
  !DEFAULT Cartesian
  !LEGAL_VALUE Cartesian
  !LEGAL_VALUE Torsion
  !LEGAL_VALUE SolidBody
  !BRIEF Optimization method
!END

!PARAMETER -d
  !TYPE double
  !DEFAULT 5.0
  !BRIEF Distance criteria from protein side-chains flexibility.
!END

!PARAMETER -s
  !TYPE string
  !REQUIRED false
  !BRIEF File name the partially optimized protein will be saved.
!END
"""


if __name__ == "__main__":
    sys.exit(main(sys.argv))



# CONFIDENTIAL. (C) 2022 Cadence Design Systems, Inc. (Cadence)
# All rights reserved.
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO CADENCE
# AND IS SUBJECT TO THE FULL PROTECTION OF COPYRIGHT AND TRADE SECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from Cadence is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact Cadence at eyesopen.com/legal if you have any questions
# about this warning.
import os
import sys
import platform
import subprocess

"""
OpenEye's current definition of 'architecture strings'.
"""


def _get_windows_platform():
    bits, name = platform.architecture()
    return ("win" + bits[:2],)


def _prepend_ucs(newname):
    if sys.version_info[:2] == (2, 7) and "ucs" not in newname:
        if sys.maxunicode == 65535:
            newname = "ucs2-" + newname
        else:
            newname = "ucs4-" + newname
    return newname


def _get_bits():
    nbits = platform.architecture()[0]
    machine = platform.machine()
    pyarch = {"64bit": "x64",
              "32bit": "x86"}[nbits]
    if machine == "aarch64":
        pyarch = "aarch64"
    return pyarch


def _get_mac_bits():
    return "universal"


def _get_mac_platform():
    return "osx", _get_mac_bits()


def _get_mac_platform_old():
    release, versioninfo, machine = platform.mac_ver()
    version = ".".join(release.split(".")[:2])
    if not version.startswith("10"):
        version = ".".join(release.split(".")[:1])
    return "osx", version, _get_mac_bits()


def _get_linux_platform():

    # Check for RHEL6, that one uses old distribution,
    # all other linux builds use generic single-build

    #if os.path.exists("/etc/redhat-release"):
    #    with open("/etc/redhat-release") as f:
    #        line = f.readline()
    #        if "release 6" in line:
    #            return "redhat", "6", "x64"

    # generic linux
    return _prepend_ucs("linux"), _get_bits()


def _get_linux_platform_old():
    if not hasattr(platform, 'linux_distribution'):
        try:
            import distro
        except ImportError:
            raise Exception("Missing linux_distribution support!")
        distname, version, extra = distro.linux_distribution(full_distribution_name=False)
    elif sys.version_info[:2] > (2, 5):
        distname, version, extra = platform.linux_distribution(full_distribution_name=False)
    else:
        distname, version, extra = platform.dist()

    distname = distname.lower()
    if "centos" in distname:
        distname = "redhat"

    if "amzn" in distname:
        distname = "amazon"
        version = "1"
        if distname == "amzn2":
            version = "2"

    if distname in ["redhat", "suse"]:
        version = version.split(".")[0]

    if "debian" in distname or "ubuntu" in distname:
        distname = "ubuntu"
        if "squeeze" in version:
            version = "10.04"

        # ubuntu12-64 alternate
        # ['ubuntu', '12.04', 'x64'] != ('ubuntu', 'wheezy/sid', 'x64')
        elif "wheezy" in version:
            version = "12.04"
        elif "trusty" in version:   # ubuntu14 beta
            version = "14.04"
        elif "jessie" in version:   # ubuntu14.04.2
            version = "14.04"
        elif "stretch" in version:  # ubuntu16.04.1
            version = "16.04"
        elif "buster" in version:   # ubuntu18.04
            version = "18.04"
        elif "bullseye" in version: # ubuntu20.04
            version = "20.04"
        elif "bookworm" in version: # ubuntu22.04
            version = "22.04"

    if not distname:
        # generic linux
        distname = platform.platform()
        if "amzn2" in distname:
            distname = "amazon"
            version = "2"
        else:
            distname = _prepend_ucs("linux")
            return distname, _get_bits()

    if (distname == "redhat" and version in ["5", "6"]):
        # only Anaconda python2.7 requires this special compilation status
        if (sys.version_info[:2] == (2, 7) and sys.maxunicode != 65535):
            distname = "anaconda-" + distname

    return distname, version, _get_bits()


def openeye_platform_old():
    if sys.platform.startswith("win"):
        return _get_windows_platform()

    if sys.platform.startswith("darwin"):
        return _get_mac_platform_old()

    if sys.platform.startswith("linux"):
        return _get_linux_platform_old()

    raise ValueError("Unrecognized platform '%s'" % sys.platform)


def openeye_platform():
    """
    Return a tuple corresponding to the (distname, version, bitness)
    of the machine being run on.

    Windows returns a single element tuple, either ('win32',) or
    ('win64',) for 32 or 64 bit respectively.

    If 'OE_PIP_ARCH' environment variable is set, return the first
    architecture specified in that string.
    """
    if "OE_PIP_ARCH" in os.environ:
        # Unlike OE_ARCH for app installs, Python only can act upon the
        # first entry in OE_PIP_ARCH. There is no way to iterate over a
        # list since the python requirements mechanism used to force the
        # download of the actual package from the metapackage isn't
        # recoverable if the first one fails.
        newname = os.environ["OE_PIP_ARCH"].split(":")[0]
        # force to use old naming
        if "old" in newname:
            return openeye_platform_old()
        # special for single builds
        if "linux" in newname:
            newname = _prepend_ucs(newname)
        # Apps use "redhat-RHEL6-...", python uses "redhat-6-..."
        # Remap to try to minimize confusion; no-op otherwise
        newname = newname.replace("redhat-RHEL", "redhat-", 1)
        return newname.split("-")

    if sys.platform.startswith("win"):
        return _get_windows_platform()

    if sys.platform.startswith("darwin"):
        return _get_mac_platform()

    if sys.platform.startswith("linux"):
        return _get_linux_platform()

    raise ValueError("Unrecognized platform '%s'" % sys.platform)


def openeye_python_version():
    """
    Return a string representation of the python version, e.g.,
    'python2.7'.

    For Python 3+, don't include the minor revision on non-Windows, just return
    'python3'.
    """
    verinfo = sys.version_info
    version = "python%i" % verinfo[0]
    if verinfo[0] <= 2 or sys.platform.startswith("win"):
        version += ".%i" % verinfo[1]
    return version


def openeye_python_compilers():
    """
    Return a list of strings for compatible compilers for this python
    interpretter. All platforms will return a single compiler.
    """
    # Is the user trying to use a non-supported system?
    if "OE_PYTHON_COMPILER" in os.environ:
        return [os.environ["OE_PYTHON_COMPILER"]]

    # Get the compiler used to compile python
    comp = platform.python_compiler()

    compilers = []

    try:
        if len(comp) > 1:
            cxx, ver = comp.split()[:2]

            cxx = cxx.lower()
            if cxx == "gcc":
                cxx = "g++"

            ver = ver.split('.') + ['0']

            # single builds
            if "linux" in '-'.join(openeye_platform()) and cxx == "g++":
                ver = '.'.join([ver[0], "x"])
            else:
                ver = '.'.join(ver[:2])

            compilers.append(cxx + ver)
    except ValueError:
        pass

    if not compilers:
        compilers.append(comp)

    return compilers



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Performing RMSD calculation between a 3D reference molecule and
# multi-conformation molecules
#############################################################################
import sys
from openeye import oechem


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    if not itf.GetBool("-verbose"):
        oechem.OEThrow.SetLevel(oechem.OEErrorLevel_Warning)

    rfname = itf.GetString("-ref")
    ifname = itf.GetString("-in")

    automorph = itf.GetBool("-automorph")
    heavy = itf.GetBool("-heavyonly")
    overlay = itf.GetBool("-overlay")

    ifs = oechem.oemolistream()
    if not ifs.open(rfname):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % rfname)

    rmol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(ifs, rmol):
        oechem.OEThrow.Fatal("Unable to read reference molecule")

    ifs = oechem.oemolistream()
    if not ifs.open(ifname):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % ifname)

    ofs = oechem.oemolostream()
    if itf.HasString("-out"):
        ofname = itf.GetString("-out")
        if not ofs.open(ofname):
            oechem.OEThrow.Fatal("Unable to open %s for writing" % ofname)
        if not overlay:
            oechem.OEThrow.Warning("Output is the same as input when overlay is false")

    for mol in ifs.GetOEMols():
        oechem.OEThrow.Info(mol.GetTitle())

        rmsds = oechem.OEDoubleArray(mol.GetMaxConfIdx())
        rmtx = oechem.OEDoubleArray(9 * mol.GetMaxConfIdx())
        tmtx = oechem.OEDoubleArray(3 * mol.GetMaxConfIdx())

        # perform RMSD for all confomers
        oechem.OERMSD(rmol, mol, rmsds, automorph, heavy, overlay, rmtx, tmtx)

        for conf in mol.GetConfs():
            cidx = conf.GetIdx()
            oechem.OEThrow.Info("Conformer %i : rmsd = %f" % (cidx, rmsds[cidx]))

            if itf.GetBool("-overlay"):
                oechem.OERotate(conf, rmtx[cidx * 9: cidx * 9 + 9])
                oechem.OETranslate(conf, tmtx[cidx * 3: cidx * 3 + 3])

        if itf.HasString("-out"):
            oechem.OEWriteMolecule(ofs, mol)

    return 0

#############################################################################


InterfaceData = """\
!BRIEF [options] [-ref <mol file>] [-in <mol file>] [-out <mol file>]

!CATEGORY "input/output options"

  !PARAMETER -ref
    !TYPE string
    !REQUIRED true
    !BRIEF input reference mol file name
    !KEYLESS 1
  !END

  !PARAMETER -in
    !ALIAS -i
    !TYPE string
    !REQUIRED true
    !BRIEF input mol file name
    !KEYLESS 2
  !END

  !PARAMETER -out
    !ALIAS -o
    !TYPE string
    !REQUIRED false
    !BRIEF output file name, this implies that -overlay should be true
    !KEYLESS 3
  !END

!END

!CATEGORY "options"

  !PARAMETER -automorph
    !TYPE bool
    !DEFAULT true
    !BRIEF assign best atom association
    !DETAIL
        If false, atoms are associated by order.
        If true, graph isomorphism is determined with symmetry perception.
  !END

  !PARAMETER -overlay
    !TYPE bool
    !DEFAULT true
    !BRIEF Minimize to the smallest RMSD
  !END

  !PARAMETER -heavyonly
    !TYPE bool
    !DEFAULT true
    !BRIEF Ignore hydrogens for RMSD calculation
  !END

  !PARAMETER -verbose
    !ALIAS -v
    !TYPE bool
    !DEFAULT false
    !BRIEF verbose
  !END

!END
"""

#############################################################################
if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oegraphsim

# @ <SNIPPET-MEM-SIM-SEARCH>
if len(sys.argv) != 2:
    oechem.OEThrow.Usage("%s <database>" % sys.argv[0])

ifs = oechem.oemolistream()
if not ifs.open(sys.argv[1]):
    oechem.OEThrow.Fatal("Cannot open database molecule file!")

# load molecules

moldb = oechem.OEMolDatabase(ifs)
nrmols = moldb.GetMaxMolIdx()

# generate fingerprints

fpdb = oegraphsim.OEFPDatabase(oegraphsim.OEFPType_Path)

emptyfp = oegraphsim.OEFingerPrint()
emptyfp.SetFPTypeBase(fpdb.GetFPTypeBase())

mol = oechem.OEGraphMol()
for idx in range(0, nrmols):
    if moldb.GetMolecule(mol, idx):
        fpdb.AddFP(mol)
    else:
        fpdb.AddFP(emptyfp)

nrfps = fpdb.NumFingerPrints()

timer = oechem.OEWallTimer()
while True:

    # read query SMILES from stdin

    sys.stdout.write("Enter SMILES> ")
    line = sys.stdin.readline()
    line = line.rstrip()
    if len(line) == 0:
        sys.exit(0)

    # parse query

    query = oechem.OEGraphMol()
    if not oechem.OESmilesToMol(query, line):
        oechem.OEThrow.Warning("Invalid SMILES string")
        continue

    # calculate similarity scores

    timer.Start()
    scores = fpdb.GetSortedScores(query, 5)
    oechem.OEThrow.Info("%5.2f seconds to search %i fingerprints" % (timer.Elapsed(), nrfps))

    hit = oechem.OEGraphMol()
    for si in scores:
        if moldb.GetMolecule(hit, si.GetIdx()):
            smi = oechem.OEMolToSmiles(hit)
            oechem.OEThrow.Info("Tanimoto score %4.3f %s" % (si.GetScore(), smi))
# @ </SNIPPET-MEM-SIM-SEARCH>



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Simple superimposition of a fit protein on to a reference protein
#############################################################################
import sys
import os
from openeye import oechem
from openeye import oespruce
import tempfile


def ReadProteinMol(ifilename):
    if oechem.OEIsReadableDesignUnit(ifilename):
        du = oechem.OEDesignUnit()
        if not oechem.OEReadDesignUnit(ifilename, du):
            oechem.OEThrow.Fatal("Unable to open %s for reading OEDesignUnit" % ifilename)
        return du
    else:
        # @ <SNIPPET-READPDB-CORRECTLY>
        ifs = oechem.oemolistream()
        ifs.SetFlavor(oechem.OEFormat_PDB, oechem.OEIFlavor_PDB_Default | oechem.OEIFlavor_PDB_DATA | oechem.OEIFlavor_PDB_ALTLOC)  # noqa        
        if not ifs.open(ifilename):
            oechem.OEThrow.Fatal("Unable to open %s for reading" % ifilename)
        mol = oechem.OEGraphMol()
        if not oechem.OEReadMolecule(ifs, mol):
            oechem.OEThrow.Fatal("Unable to read molecule from %s" % ifilename)
        # @ </SNIPPET-READPDB-CORRECTLY>
        return mol


def ReadSiteResidues(in_file):
    site_residues = []
    with open(in_file, "r") as f:
        lines = f.read().splitlines()

        for line in lines:
            if line.strip() == "":
                continue
            site_residues.append(line)
    return site_residues


def main(argv=[__name__]):
    if len(argv) < 3:
        oechem.OEThrow.Usage(f"{argv[0]} <reference protein PDB> <fit protein PDB> [global|ddm|weighted|sse|site] [site-residue file] [nowrite]")  # noqa

    inp_method = "global"
    if len(argv) > 3:
        inp_method = argv[3]

    site_file = None
    do_write = True
    if inp_method == "site":
        if len(argv) > 4:
            site_file = argv[4]
        else:
            oechem.OEThrow.Warning(f"A text file containing site residues must be provided for using the SiteSequence method\n")
            sys.exit(1)

        if not os.path.isfile(site_file):
            oechem.OEThrow.Warning(f"File not found: {site_file}\n")
            sys.exit(1)
        nowrite_argidx = 5
    else:
        nowrite_argidx = 4

    if len(argv) > nowrite_argidx:
        if argv[nowrite_argidx] != "nowrite":
            oechem.OEThrow.Warning(f"{argv[nowrite_argidx]} is not a valid option.\n")
            sys.exit(1)
        else:
            do_write = False

    ref_prot_file = argv[1]
    fit_prot_file = argv[2]

    ref_prot = ReadProteinMol(ref_prot_file)
    fit_prot = ReadProteinMol(fit_prot_file)

    method = oespruce.OEGetSuperposeMethodFromName(inp_method)
    if method == oespruce.OESuperposeMethod_Undefined:
        oechem.OEThrow.Warning(f"{inp_method} superposition method is not supported.\n")
        sys.exit(1)

    opts = oespruce.OESuperposeOptions(method)
    print(f"Superposing {fit_prot_file} to {ref_prot_file} using {oespruce.OEGetSuperposeMethodName(method)}.\n")

    results = oespruce.OESuperposeResults()
    superposition = oespruce.OESuperpose(opts)
    if opts.GetMethod() == oespruce.OESuperposeMethod_Site and not isinstance(ref_prot, oechem.OEDesignUnit):
        site_residues = ReadSiteResidues(site_file)
        superposition.SetupRef(ref_prot, site_residues)
    else:
        superposition.SetupRef(ref_prot)
    superposition.Superpose(results, fit_prot)

    rmsd = results.GetRMSD()
    seqscore = results.GetSeqScore()
    tanimoto = results.GetTanimoto()

    results.Transform(fit_prot)

    if opts.GetMethod() == oespruce.OESuperposeMethod_SSE:
        print(f"Tanimoto: {tanimoto:4.2f}\n")
    else:
        print(f"RMSD: {rmsd:4.2f} Angstroms.")
        print(f"SeqScore: {seqscore:d}.\n")

    if do_write:
        temp_dir = tempfile.mkdtemp()
        if isinstance(fit_prot, oechem.OEDesignUnit):
            str_pos = fit_prot_file.find(".oedu")
            base_name = fit_prot_file[0:str_pos]
            output_fit_file = os.path.join(temp_dir, base_name + "_sp.oedu")
            ofs = oechem.oeofstream(output_fit_file)
            oechem.OEWriteDesignUnit(ofs, fit_prot)
        else:
            str_pos = fit_prot_file.find(".pdb")
            base_name = fit_prot_file[0:str_pos]
            output_fit_file = os.path.join(temp_dir, base_name + "_sp.oeb.gz")
            ofs = oechem.oemolostream(output_fit_file)
            oechem.OEWriteMolecule(ofs, fit_prot)

        print(f"Superimposed fit protein was written to {output_fit_file}.\n")


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem


# @ <SNIPPET-MOL-WEIGHT>
def CalculateMolecularWeight(mol):
    implicitH = 0
    weight = 0.0
    for atom in mol.GetAtoms():
        elemno = atom.GetAtomicNum()
        mass = atom.GetIsotope()
        implicitH += atom.GetImplicitHCount()
        if elemno != 0 and mass != 0 and oechem.OEIsCommonIsotope(elemno, mass):
            weight += oechem.OEGetIsotopicWeight(elemno, mass)
        else:
            weight += oechem.OEGetAverageWeight(elemno)
    weight += implicitH * oechem.OEGetAverageWeight(oechem.OEElemNo_H)
    return weight


# @ </SNIPPET-MOL-WEIGHT>
mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "C(O)(=O)c1cccc2c1[nH]c(C3CCCc4c3cccc4)c2")
print("molecular weight=", CalculateMolecularWeight(mol))
# @ </SNIPPET>



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oedepict
from openeye import oegrapheme


def ImportMolecule(filename):

    ifs = oechem.oemolistream()
    if not ifs.open(filename):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % filename)

    mol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(ifs, mol):
        oechem.OEThrow.Fatal("Unable to read molecule in %s" % filename)
    return mol


if len(sys.argv) != 3:
    oechem.OEThrow.Usage("%s <ref> <fit>" % sys.argv[0])

refmol3D = ImportMolecule(sys.argv[1])
fitmol3D = ImportMolecule(sys.argv[2])

# @ <SNIPPET-PREPARE-ALIGNED-DEPICTION-FROM-3D>
refmol2D = oechem.OEGraphMol(refmol3D)
oegrapheme.OEPrepareDepictionFrom3D(refmol2D)

fitmol2D = oechem.OEGraphMol(fitmol3D)
oegrapheme.OEPrepareAlignedDepictionFrom3D(fitmol2D, fitmol3D, refmol2D, refmol3D)

width, height = 300, 300
opts = oedepict.OE2DMolDisplayOptions(width, height, oedepict.OEScale_AutoScale)
refscale = oedepict.OEGetMoleculeScale(refmol2D, opts)
fitscale = oedepict.OEGetMoleculeScale(fitmol2D, opts)
opts.SetScale(min(refscale, fitscale))

refdisp = oedepict.OE2DMolDisplay(refmol2D, opts)
oedepict.OERenderMolecule("OEPrepareAlignedDepictionFrom3D-ref-2D.png", refdisp)

fitdisp = oedepict.OE2DMolDisplay(fitmol2D, opts)
oedepict.OERenderMolecule("OEPrepareAlignedDepictionFrom3D-fit-2D.png", fitdisp)

# @ </SNIPPET-PREPARE-ALIGNED-DEPICTION-FROM-3D>
oedepict.OERenderMolecule("OEPrepareAlignedDepictionFrom3D-ref-2D.pdf", refdisp)
oedepict.OERenderMolecule("OEPrepareAlignedDepictionFrom3D-fit-2D.pdf", fitdisp)



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Print the phi and psi rotatable angles for each residues in a protein
#############################################################################
import sys
from openeye import oechem


def ShowPhiPsi(ifs):
    nrmol = 0
    mol = oechem.OEGraphMol()
    while oechem.OEReadMolecule(ifs, mol):
        nrmol += 1
        print("================================================")
        print("Molecule: %d  Title: %s" % (nrmol, mol.GetTitle()))

        if not oechem.OEHasResidues(mol):
            oechem.OEPerceiveResidues(mol, oechem.OEPreserveResInfo_All)
        hv = oechem.OEHierView(mol)

        for res in hv.GetResidues():
            if not oechem.OEIsStandardProteinResidue(res):
                continue

            phi = oechem.OEGetPhi(res)
            psi = oechem.OEGetPsi(res)

            oeres = res.GetOEResidue()
            print("  %s %s %d (PHI=%.2f, PSI=%.2f)" % (oeres.GetName(),
                                                       oeres.GetChainID(),
                                                       oeres.GetResidueNumber(),
                                                       phi, psi))


if __name__ == "__main__":
    if len(sys.argv) != 2:
        oechem.OEThrow.Usage("phipsi.py <infile>")
    ifs = oechem.oemolistream()
    if not ifs.open(sys.argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % sys.argv[1])
    ShowPhiPsi(ifs)



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.
import os
import sys

from openeye import oechem
from openeye import oesitehopper


def main(args):
    itf = oechem.OEInterface()
    oechem.OEConfigure(itf, interface)
    if oechem.OECheckHelp(itf, args):
        return 0
    if not oechem.OEParseCommandLine(itf, args):
        return 1

    dbname = itf.GetString("-shdb")
    outfile = None
    if itf.HasString("-out"):
        outfile = itf.GetString("-out")

    shdb = oesitehopper.OESiteHopperDatabase()
    if not os.path.isfile(dbname) or not shdb.Open(dbname, oesitehopper.OESiteHopperDatabaseMode_READONLY):
        print(f"unable to open {dbname} for reading")
        return 1

    if outfile and not oechem.OEIsWriteableDesignUnit(outfile):
        print(f"{outfile} is not a valid OEDesignUnit filename")
        return 1

    if itf.HasUnsignedInt("-index") and itf.HasString("-title"):
        print("can't use both -index and -title together")
        return 1

    du = oechem.OEDesignUnit()
    if itf.HasUnsignedInt("-index"):
        index = itf.GetUnsignedInt("-index")
        if shdb.GetDesignUnit(du, index):
            if outfile and oechem.OEWriteDesignUnit(outfile, du):
                print(f"Wrote DU {du.GetTitle()} to {outfile}")
                return 0
            else:
                print(f"ID: {index}, TITLE: {shdb.GetTitle(index)}")
        else:
            print("unable to retrieve DU with IDX = {index}")
            return 1
    elif itf.HasString("-title"):
        title = itf.GetString("-title")
        indices = shdb.GetIDByTitle(title)
        if len(indices) == 0:
            print("No DUs found with title matching '{title}'")
            return False
        ofs = None
        if outfile:
            ofs = oechem.oeofstream(outfile)
        for index in indices:
            if ofs and shdb.GetDesignUnit(du, index):
                oechem.OEWriteDesignUnit(ofs, du)
                print(f"Wrote DU {du.GetTitle()} to {outfile}")
            else:
                print(f"ID: {index}, TITLE: {shdb.GetTitle(index)}")
    else:
        print("Please try -index or -title for DUs to extract")


interface = """
!BRIEF get_designunit.py [-index IDX | -title TITLE] <shdb> <oedu file>

!CATEGORY I/O

    !PARAMETER -shdb 1
        !TYPE string
        !REQUIRED true
        !VISIBILITY simple
        !BRIEF Input OESiteHopperDatabase
    !END

    !PARAMETER -out 2
        !TYPE string
        !REQUIRED false
        !VISIBILITY simple
        !BRIEF Output .oedu file. If empty, just print out titles of matched DUs
    !END
!END

!CATEGORY Choice 99
    !PARAMETER -index
        !TYPE unsigned
        !REQUIRED false
        !VISIBILITY simple
        !BRIEF Single index of OEDU to extract from database
    !END

    !PARAMETER -title
        !TYPE string
        !REQUIRED false
        !VISIBILITY simple
        !BRIEF Title for substring match to extract from database
    !END
!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Script to prepare proteins into design units
#############################################################################
import sys
import os
from openeye import oechem
from openeye import oegrid
from openeye import oespruce


def main(argv=sys.argv):

    if len(argv) < 3 or len(argv) > 5:
        oechem.OEThrow.Usage(
            "%s <infile> <site_residue> [<mtzfile>] [<loopdbfile>]" % argv[0]
        )

    ifs = oechem.oemolistream()
    ifile = argv[1]
    if not ifs.open(ifile):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % ifile)

    site_residue = argv[2]

    include_loop = False
    include_ed = False
    if len(argv) > 3:
        if len(argv) == 5 or (len(argv) == 4 and "mtz" in argv[3]):
            edfile = argv[3]
            ed = oegrid.OESkewGrid()
            if not oegrid.OEReadMTZ(edfile, ed, oegrid.OEMTZMapType_Fwt):
                oechem.OEThrow.Fatal(
                    "Unable to read electron density file %s" % edfile
                )  # noqa
            include_ed = True
        if len(argv) == 5:
            loopfile = argv[4]
            include_loop = True
        elif len(argv) == 4 and "mtz" not in argv[3]:
            loopfile = argv[3]
            include_loop = True

    if ifs.GetFormat() not in [oechem.OEFormat_PDB, oechem.OEFormat_CIF]:
        oechem.OEThrow.Fatal("Only works for .pdb or .cif input files")

    ifs.SetFlavor(
        oechem.OEFormat_PDB,
        oechem.OEIFlavor_PDB_Default
        | oechem.OEIFlavor_PDB_DATA
        | oechem.OEIFlavor_PDB_ALTLOC,
    )  # noqa

    mol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(ifs, mol):
        oechem.OEThrow.Fatal("Unable to read molecule from %s" % ifile)

    metadata = oespruce.OEStructureMetadata()
    opts = oespruce.OEMakeDesignUnitOptions()
    opts.GetPrepOptions().GetBuildOptions().GetLoopBuilderOptions().SetBuildTails(False)
    if include_loop:
        opts.GetPrepOptions().GetBuildOptions().GetLoopBuilderOptions().SetLoopDBFilename(
            loopfile
        )

    if include_ed:
        design_units = oespruce.OEMakeDesignUnits(mol, ed, metadata, opts, site_residue)
    else:
        design_units = oespruce.OEMakeDesignUnits(mol, metadata, opts, site_residue)

    base_name = os.path.basename(ifile)[:-4] + "_DU_{}.oedu"
    for i, design_unit in enumerate(design_units):
        oechem.OEWriteDesignUnit(base_name.format(i), design_unit)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem
import sys


InterfaceData = """
!BRIEF UsingOEInterfaceHelp.py [-d <delimiter>] [-o] <output> [-i] <input1> <input2> ...
!PARAMETER -delim
  !ALIAS -d
  !TYPE string
  !SIMPLE true
  !DEFAULT _
  !BRIEF Title delimiter
  !DETAIL
         This is the value given to the OEChem function OEAddMols to
         separate the titles of the input molecules in the output.
!END
!PARAMETER -output
  !ALIAS -o
  !TYPE string
  !SIMPLE true
  !REQUIRED true
  !KEYLESS 1
  !BRIEF The output file
  !DETAIL
         The molecule file to output to, can be any file format
         OEChem supports.
!END
!PARAMETER -inputs
  !ALIAS -i
  !TYPE string
  !SIMPLE true
  !REQUIRED true
  !LIST true
  !KEYLESS 2
  !BRIEF The input files
  !DETAIL
         A list of molecule files to add together. Note, only the
         first molecule from every file will be added.
!END
"""


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    outmol = oechem.OEGraphMol()
    for fname in itf.GetStringList("-inputs"):
        ims = oechem.oemolistream(fname)

        inmol = oechem.OEGraphMol()
        oechem.OEReadMolecule(ims, inmol)

        oechem.OEAddMols(outmol, inmol, itf.GetString("-delim"))

    oms = oechem.oemolostream(itf.GetString("-output"))
    oechem.OEWriteMolecule(oms, outmol)


if __name__ == "__main__":
    sys.exit(main(sys.argv))
# @ </SNIPPET>



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem

pattern = oechem.OEGraphMol()
target = oechem.OEGraphMol()
oechem.OESmilesToMol(pattern, "c1(cc(nc2c1C(CCC2)Cl)CCl)O")
oechem.OESmilesToMol(target, "c1(c2c(nc(n1)CF)COC=C2)N")

# @ <SNIPPET-EXPR>
atomexpr = oechem.OEExprOpts_DefaultAtoms
bondexpr = oechem.OEExprOpts_DefaultBonds
# @ </SNIPPET-EXPR>

patternQ = oechem.OEQMol(pattern)
# generate query with atom and bond expression options
# @ <SNIPPET-BUILDEXPR>
patternQ.BuildExpressions(atomexpr, bondexpr)
# @ </SNIPPET-BUILDEXPR>
mcss = oechem.OEMCSSearch(patternQ)

unique = True
count = 1
# loop over matches
for match in mcss.Match(target, unique):
    print("Match %d:" % count)
    print("Number of matched atoms: %d" % match.NumAtoms())
    print("Number of matched bonds: %d" % match.NumBonds())
    # create match subgraph
    m = oechem.OEGraphMol()
    oechem.OESubsetMol(m, match, True)
    print("match smiles = %s" % oechem.OEMolToSmiles(m))
    count += 1
# @ </SNIPPET>



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Performs SMARTS search on substructure database file
#############################################################################
import sys
from openeye import oechem


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData)

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line.")

    # check parameters

    c = itf.GetBool("-count")
    t = itf.GetBool("-titles")
    o = itf.HasString("-out")

    if not((c and not t and not o) or (not c and t and not o) or (not c and not t and o)):
        oechem.OEThrow.Fatal("Counting (-c) or outputting titles (-t) or molecules (-o) "
                             "must be specified and are mutually exclusive.")

    ofs = oechem.oemolostream()
    if itf.HasString("-out"):
        ofname = itf.GetString("-out")
        if not ofs.open(ofname):
            oechem.OEThrow.Fatal("Cannot open output file!")

    dbfname = itf.GetString("-db")
    smarts = itf.GetString("-smarts")
    nrthreads = itf.GetUnsignedInt("-nrthreads")
    maxmatches = itf.GetUnsignedInt("-maxmatches")

    # initialize query

    qmol = oechem.OEQMol()
    if not oechem.OEParseSmarts(qmol, smarts):
        oechem.OEThrow.Fatal("Unable to parse SMARTS pattern: %s" % smarts)

    # initialize substructure search database

    screentype = oechem.OEGetSubSearchScreenType(oechem.OESubSearchScreenType_SMARTS)

    if not oechem.OEIsValidSubSearchDatabase(dbfname, screentype):
        oechem.OEThrow.Fatal("Invalid SMARTS substructure search database file!")

    ssdb = oechem.OESubSearchDatabase(oechem.OESubSearchDatabaseType_Default, nrthreads)
    tracer = oechem.OEConsoleProgressTracer()
    if not ssdb.Open(dbfname, tracer):
        oechem.OEThrow.Fatal("Substructure search database can not be initialized!")

    screenstr = screentype.GetName()
    infomsg = "Using %d processor(s) to search database with '%s'"
    oechem.OEThrow.Info(infomsg % (ssdb.NumProcessors(), screenstr))

    # search database

    if itf.GetBool("-count"):
        oechem.OEThrow.Info("Number of hits: %d" % ssdb.NumMatches(qmol))
    else:
        query = oechem.OESubSearchQuery(qmol, maxmatches)
        result = oechem.OESubSearchResult()
        status = ssdb.Search(result, query)

        print("Search status = ", oechem.OESubSearchStatusToName(status))

        print("Number of targets  = ", result.NumTargets())
        print("Number of screened = ", result.NumScreened())
        print("Number of searched = ", result.NumSearched())
        print("Number of total matches = ", result.NumTotalMatches())
        print("Number of kept  matches = ", result.NumMatches())

        if itf.GetBool("-titles"):
            print("Matches:")
            for index in result.GetMatchIndices():
                print(ssdb.GetTitle(index))

        elif itf.HasString("-out"):
            mol = oechem.OEGraphMol()
            for index in result.GetMatchIndices():
                if ssdb.GetMolecule(mol, index):
                    oechem.OEWriteMolecule(ofs, mol)

    return 0

#############################################################################


InterfaceData = """\
!BRIEF [options] -db <database> -s <smarts> -nrthreads <unsigned int>

!CATEGORY "input/output options"

  !PARAMETER -database 1
    !ALIAS -db
    !TYPE string
    !REQUIRED true
    !VISIBILITY simple
    !BRIEF Input substructure search database filename
  !END

  !PARAMETER -smarts 2
    !ALIAS -s
    !TYPE string
    !REQUIRED true
    !BRIEF SMARTS pattern, quote for safety
  !END

!END

!CATEGORY "search types"

  !PARAMETER -count
    !ALIAS -c
    !TYPE bool
    !DEFAULT false
    !BRIEF Output count of number matched
  !END

  !PARAMETER -titles
    !ALIAS -t
    !TYPE bool
    !DEFAULT false
    !BRIEF Output title of matches
  !END

  !PARAMETER -out
    !ALIAS -o
    !TYPE string
    !BRIEF Output molecule filename of matches
  !END

!END

!CATEGORY "other options"

  !PARAMETER -nrthreads
    !TYPE unsigned
    !REQUIRED  true
    !DEFAULT 1
    !BRIEF  Number of processors used (zero means all available)
  !END

  !PARAMETER -maxmatches
    !ALIAS -max
    !TYPE unsigned
    !DEFAULT 1000
    !BRIEF The maximum number of matches returned in case of parameters (-titles) and (-out)
  !END

!END
"""

#############################################################################
if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Apply a transformation
#############################################################################
import sys
from openeye import oechem


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    opts = oechem.OEUniMolecularRxnOptions()

    opts.SetStrictSmirks(itf.GetBool("-strict"))
    opts.SetClearCoordinates(itf.GetBool("-clearcoords"))
    opts.SetValidateKekule(itf.GetBool("-validkek"))
    opts.SetMaxMatches(itf.GetInt("-max"))

    altered = itf.GetString("-alteredtag")
    opts.SetAlteredTag("")
    if altered:
        opts.SetAlteredTag(altered)

    fixval = itf.GetString("-fixval")
    if fixval.upper() == "EXPLICIT" or fixval.upper() == "NONE":
        opts.SetFixValence(oechem.OEUniMolecularRxnFixValence_Explicit)
    elif fixval.upper() == "ALTERED":
        opts.SetFixValence(oechem.OEUniMolecularRxnFixValence_Altered)
    elif fixval.upper() == "ALL":
        opts.SetFixValence(oechem.OEUniMolecularRxnFixValence_All)
    else:
        oechem.Error("Unknown fix valence request: {}".format(fixval))

    xform = itf.GetString("-smirks")
    xformname = None
    if " " in xform:
        xform, xformname = xform.split(" ")[:2]

    qrxn = oechem.OEQMol()
    if not oechem.OEParseSmirks(qrxn, xform):
        oechem.Fatal("SMIRKS parse error: {}".format(xform))

    umr = oechem.OEUniMolecularRxn()
    if not umr.Init(xform, opts):
        oechem.Fatal("Error initializing OEUniMolecularRxn: {}".format(xform))

    ifs = oechem.oemolistream()
    if not ifs.open(itf.GetString("-in")):
        oechem.OEThrow.Fatal(
            "Unable to open {} for reading".format(itf.GetString("-in"))
        )

    ofs = oechem.oemolostream()
    if not ofs.open(itf.GetString("-out")):
        oechem.OEThrow.Fatal(
            "Unable to open {} for writing".format(itf.GetString("-out"))
        )

    outfails = None
    if itf.HasString("-noxform"):
        print('noform=[{}]'.format(itf.GetString("-noxform")))
        outfails = oechem.oemolostream()
        if not outfails.open(itf.GetString("-noxform")):
            oechem.OEThrow.Fatal(
                "Unable to open failure file {} for writing".format(itf.GetString("-noxform"))
            )

    all2output = itf.GetBool("-passfail")
    asrxn = itf.GetBool("-asrxn")

    outmol = oechem.OEGraphMol()
    for mol in ifs.GetOEGraphMols():
        title = mol.GetTitle()
        insmi = oechem.OEMolToSmiles(mol)
        status = umr(mol)
        if status or all2output:
            if not asrxn:
                if status and xformname:
                    mol.SetTitle("{}({})".format(xformname, mol.GetTitle()))
                if (
                    oechem.OEWriteMolecule(ofs, mol)
                    != oechem.OEWriteMolReturnCode_Success
                ):
                    oechem.Fatal(
                        "Error writing molecule: {}".format(oechem.OEMolToSmiles(mol))
                    )
            else:
                if not status:
                    outmol = mol
                else:
                    oechem.OESmilesToMol(
                        outmol, "{}>>{}".format(insmi, oechem.OEMolToSmiles(mol))
                    )
                    if xformname:
                        outmol.SetTitle("{}({})".format(xformname, title))
                    else:
                        outmol.SetTitle(title)
                if (
                    oechem.OEWriteMolecule(ofs, outmol)
                    != oechem.OEWriteMolReturnCode_Success
                ):
                    oechem.Fatal(
                        "Error writing molecule: {}".format(
                            oechem.OEMolToSmiles(outmol)
                        )
                    )
        elif outfails and not status:
            if (
                oechem.OEWriteMolecule(outfails, mol)
                != oechem.OEWriteMolReturnCode_Success
            ):
                oechem.Fatal(
                    "Error writing molecule: {}".format(oechem.OEMolToSmiles(mol))
                )
    return 0


InterfaceData = """
!BRIEF -smirks SMIRKS -in <input> -out <output>
    !CATEGORY I/O
        !PARAMETER -smirks 1
          !ALIAS -xform
          !TYPE string
          !REQUIRED true
          !BRIEF Transformation SMIRKS
          !KEYLESS 1
        !END
        !PARAMETER -in 2
          !ALIAS -i
          !TYPE string
          !REQUIRED true
          !BRIEF Input file name
          !KEYLESS 2
        !END
        !PARAMETER -out 3
          !ALIAS -o
          !ALIAS -success
          !TYPE string
          !REQUIRED true
          !BRIEF Output file name
          !KEYLESS 3
        !END
        !PARAMETER -noxform 4
          !ALIAS -failure
          !TYPE string
          !REQUIRED false
          !BRIEF Output file name for untransformed structures
        !END
    !END
    !CATEGORY Options
        !PARAMETER -strict 1
          !ALIAS -strictsmirks
          !TYPE bool
          !REQUIRED false
          !DEFAULT true
          !BRIEF  requested strict flag which controls the interpretation of the transformation SMIRKS (true:Daylight convention, false:OpenEye convention)
        !END
        !PARAMETER -clearcoords 2
          !TYPE bool
          !REQUIRED false
          !DEFAULT true
          !BRIEF whether to clear coordinates for transformed products
        !END
        !PARAMETER -validkek 3
          !ALIAS -validkekule
          !TYPE bool
          !REQUIRED false
          !DEFAULT true
          !BRIEF whether the transformation validates the Kekule form of the transformed products
        !END
        !PARAMETER -fixval 4
          !TYPE string
          !REQUIRED false
          !DEFAULT Explicit
          !BRIEF type of valence correction to apply to the transformed products: Explicit(None), Altered, All
        !END
        !PARAMETER -max 5
          !ALIAS -maxxforms
          !TYPE int
          !REQUIRED false
          !DEFAULT 10
          !BRIEF maximum number of transformation to apply to each processed molecule
        !END
        !PARAMETER -alteredtag 6
          !TYPE string
          !REQUIRED false
          !DEFAULT None
          !BRIEF A generic data tag to mark altered atom information from transformed products
        !END
        !PARAMETER -passfail 7
          !TYPE bool
          !REQUIRED false
          !DEFAULT false
          !BRIEF If true, include untransformed structures in -out
        !END
        !PARAMETER -asrxn 8
          !TYPE bool
          !REQUIRED false
          !DEFAULT false
          !BRIEF If true, output the transformation as a reaction
        !END
    !END
!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oequacpac


def AssignChargesByName(mol, name):
    if name == "noop":
        return oequacpac.OEAssignCharges(mol, oequacpac.OEChargeEngineNoOp())
    elif name == "clear":
        return oequacpac.OEAssignCharges(mol, oequacpac.OEClearCharges())
    elif name == "formal":
        return oequacpac.OEAssignCharges(mol, oequacpac.OEFormalToPartialCharges())
    elif name == "initial":
        return oequacpac.OEAssignCharges(mol, oequacpac.OEInitialCharges())
    elif name == "gasteiger":
        return oequacpac.OEAssignCharges(mol, oequacpac.EGasteigerCharges())
    elif name == "mmff" or name == "mmff94":
        # @ <SNIPPET-ASSIGN-CHARGES-MMFF>
        if oequacpac.OEAssignCharges(mol, oequacpac.OEMMFF94Charges()):
            # ...
            # @ </SNIPPET-ASSIGN-CHARGES-MMFF>
            return True
        else:
            return False
    elif name == "am1":
        # @ <SNIPPET-ASSIGN-CHARGES-OPTIONS-PARAM>
        optimizationSetting = False
        if oequacpac.OEAssignCharges(mol, oequacpac.OEAM1Charges(optimizationSetting)):
            # ...
            # @ </SNIPPET-ASSIGN-CHARGES-OPTIONS-PARAM>
            return True
        else:
            return False
    elif name == "am1bcc":
        # @ <SNIPPET-ASSIGN-CHARGES-OPTIONS-METHOD>
        chargeEngine = oequacpac.OEAM1BCCCharges()
        chargeEngine.SetSymmetrize(False)
        if oequacpac.OEAssignCharges(mol, chargeEngine):
            # ...
            # @ </SNIPPET-ASSIGN-CHARGES-OPTIONS-METHOD>
            return True
        else:
            return False
    elif name == "amber" or name == "amberff94":
        return oequacpac.OEAssignCharges(mol, oequacpac.OEAmberFF94Charges())
    elif name == "am1bccelf10":
        return oequacpac.OEAssignCharges(mol, oequacpac.OEAM1BCCELF10Charges())
    return False


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData)

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    ims = oechem.oemolistream()

    inputFile = itf.GetString("-in")
    if not ims.open(inputFile):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % inputFile)

    mol = oechem.OEMol()
    if not oechem.OEReadMolecule(ims, mol):
        oechem.OEThrow.Fatal("Cannot read from %s" % inputFile)

    oms = oechem.oemolostream()

    outFile = itf.GetString("-out")
    if not oms.open(outFile):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % outFile)

    chargeName = itf.GetString("-charge")

    if not AssignChargesByName(mol, chargeName):
        oechem.OEThrow.Fatal("Unable to assign %s charges to %s" % (chargeName, inputFile))
    else:
        oechem.OEWriteMolecule(oms, mol)

    oms.close()

#############################################################################
# INTERFACE
#############################################################################


InterfaceData = '''
!BRIEF AssignChargesDoc <inmol> [<outmol>]

!CATEGORY "input/output options :"
   !PARAMETER -in
      !ALIAS -i
      !TYPE string
      !BRIEF Input molecule
      !VISIBILITY simple
      !REQUIRED true
      !KEYLESS 1
   !END

   !PARAMETER -out
      !ALIAS -o
      !TYPE string
      !DEFAULT oeassigncharges.oeb.gz
      !BRIEF Output molecule (usually an oeb)
      !VISIBILITY simple
      !REQUIRED false
      !KEYLESS 2
   !END
!END

!CATEGORY "Charging options :"
   !PARAMETER -charge
      !ALIAS -c
      !TYPE string
      !LEGAL_VALUE noop
      !LEGAL_VALUE clear
      !LEGAL_VALUE formal
      !LEGAL_VALUE initial
      !LEGAL_VALUE gasteiger
      !LEGAL_VALUE mmff
      !LEGAL_VALUE mmff94
      !LEGAL_VALUE am1
      !LEGAL_VALUE am1bcc
      !LEGAL_VALUE amber
      !LEGAL_VALUE amberff94
      !LEGAL_VALUE am1bccelf10
      !DEFAULT mmff94
      !BRIEF which set of charges to apply
      !SIMPLE true
      !REQUIRED false
   !END
!END
'''

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem


mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "[H][C@]1(NC[C@@H](CC1CO[C@H]2CC[C@@H](CC2)O)N)[H]")

for atom in mol.GetAtoms():
    if atom.IsChiral() and not atom.HasStereoSpecified(oechem.OEAtomStereo_Tetrahedral):
        v = []
        for neigh in atom.GetAtoms():
            v.append(neigh)
        atom.SetStereo(v, oechem.OEAtomStereo_Tetra, oechem.OEAtomStereo_Left)

print(oechem.OEMolToSmiles(mol))
# @ </SNIPPET>



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oegraphsim

mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "c1ccccc1")

# @ <SNIPPET-MAKE-LINGO-1>
fp = oegraphsim.OEFingerPrint()
oegraphsim.OEMakeLingoFP(fp, mol)
# @ </SNIPPET-MAKE-LINGO-1>

print(fp.GetFPTypeBase().GetFPTypeString())

# @ <SNIPPET-MAKE-LINGO-2>
oegraphsim.OEMakeFP(fp, mol, oegraphsim.OEFPType_Lingo)
# @ </SNIPPET-MAKE-LINGO-2>

print(fp.GetFPTypeBase().GetFPTypeString())



# CONFIDENTIAL. (C) 2022 Cadence Design Systems, Inc. (Cadence)
# All rights reserved.
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO CADENCE
# AND IS SUBJECT TO THE FULL PROTECTION OF COPYRIGHT AND TRADE SECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from Cadence is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact Cadence at eyesopen.com/legal if you have any questions
# about this warning.
"""
 Test suite for OpenEye Toolkits
"""

import os
import sys
import unittest
from scripttest import TestFileEnvironment


class OETestCase(unittest.TestCase):
    """
    Base class for all tests
    """

    def setUp(self):

        import openeye.tests
        import openeye.examples
        import openeye.docexamples

        self.env = TestFileEnvironment('./test-output')

        self.DATA_DIR = '{0}/data'.format(os.path.dirname(openeye.tests.__file__))
        self.EXAMPLES_DIR = '{0}'.format(os.path.dirname(openeye.examples.__file__))
        self.DOCEXAMPLES_DIR = '{0}'.format(os.path.dirname(openeye.docexamples.__file__))

    def run_example(self, *args, **kwargs):
        return self.env.run(sys.executable, *args, **kwargs)


def check_fastrocs():
    try:
        from openeye.oefastrocs import OEFastROCSGPUStatus
        return OEFastROCSGPUStatus()
    except ImportError:
        return -1

def check_cuda_grapshim():
    from openeye import oegraphsim
    return oegraphsim.OEGraphsimIsGPUReady()

def check_fastomega():
    from openeye import oeomega
    return oeomega.OEOmegaIsGPUReady()

def check_license(license_code):
    """
    Check the toolkit license
    :param: license_code
    """

    from openeye.oemedchem import OEMedChemIsLicensed
    from openeye.oechem import OEChemIsLicensed
    from openeye.oedepict import OEDepictIsLicensed
    from openeye.oedocking import OEDockingIsLicensed
    from openeye.oegrapheme import OEGraphemeIsLicensed
    from openeye.oegraphsim import OEGraphSimIsLicensed
    from openeye.oeiupac import OEIUPACIsLicensed
    from openeye.oemolprop import OEMolPropIsLicensed
    from openeye.oeomega import OEOmegaIsLicensed
    from openeye.oequacpac import OEQuacPacIsLicensed
    from openeye.oeshape import OEShapeIsLicensed
    from openeye.oespicoli import OESpicoliIsLicensed
    from openeye.oespruce import OESpruceIsLicensed
    from openeye.oeszybki import OESzybkiIsLicensed
    from openeye.oeszmap import OESzmapIsLicensed
    from openeye.oezap import OEZapIsLicensed

    license_status = {
        'medchem': OEMedChemIsLicensed(),
        'oechem': OEChemIsLicensed(),
        'depict': OEDepictIsLicensed(),
        'docking': OEDockingIsLicensed(),
        'grapheme': OEGraphemeIsLicensed(),
        'graphsim': OEGraphSimIsLicensed(),
        'lexichem': OEIUPACIsLicensed(),
        'molprop': OEMolPropIsLicensed(),
        'omega': OEOmegaIsLicensed(),
        'quacpac': OEQuacPacIsLicensed(),
        'shape': OEShapeIsLicensed(),
        'spruce': OESpruceIsLicensed(),
        'spicoli': OESpicoliIsLicensed(),
        'szmap': OESzmapIsLicensed(),
        'szybki': OESzybkiIsLicensed(),
        'zap': OEZapIsLicensed()
    }

    try:
        from openeye.oefastrocs import OEFastROCSIsLicensed
        license_status["fastrocs"] = OEFastROCSIsLicensed()
    except ImportError:
        print("Fastrocs is not available in this package... skipping")
        license_status["fastrocs"] = False

    return license_status[license_code]



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oeff


# //////////////////////////////////////////////////////////////////////////
# The following function displays how to use a checkpoint during function //
# optimization.  A simple quadradic equation is minimized for which the   //
# analytical gradient is provided but the second derivative is not.       //
# //////////////////////////////////////////////////////////////////////////


class Function(oeff.OEFunc1):
    def __init__(self):
        oeff.OEFunc1.__init__(self)
        pass

    def begin(self):
        pass

    def NumVar(self):
        return 1

    def __call__(self, x, g=None):
        if isinstance(x, oechem.OEDoubleArray):
            if g is not None:
                g[0] = 2.0*x[0]-7.0
                return x[0]*x[0]-7*x[0]+63
            else:
                return x[0]*x[0]-7*x[0]+63
        else:
            x1 = oechem.OEDoubleArray(x, self.NumVar(), False)
            if g is not None:
                g1 = oechem.OEDoubleArray(g, self.NumVar(), False)
                g1[0] = 2.0*x1[0]-7.0
                return x1[0]*x1[0]-7*x1[0]+63
            else:
                return x1[0]*x1[0]-7*x1[0]+63


class ChkPt(oeff.OECheckpoint0):
    def __init__(self):
        oeff.OECheckpoint0.__init__(self)
        pass

    def __call__(self, iteration, nvar, fval, var, state):
        # Intermediate information during optimization
        var1 = oechem.OEDoubleArray(var, 1, False)
        oechem.OEThrow.Info("iteration: %d x: %d value: %d state: %d"
                            % (iteration, var1[0], fval, state))

        # To demonstrate how to force quitting optimization from checkpoint
        # this returns false when iteration is 5
        if iteration >= 5:
            return False
        else:
            return True


def main(args):
    if len(args) != 2:
        oechem.OEThrow.Usage("%s <initial guess>" % args[0])

    x = oechem.OEDoubleArray(1)
    try:
        x[0] = float(args[1])
    except ValueError:
        oechem.OEThrow.Usage("%s <initial guess (expecting a number)>" % args[0])

    func = Function()

    # Calculate function value at given x
    value = func(x)
    oechem.OEThrow.Info("Function value at x = %d is %d" % (x[0], value))

    # Optimize function using BFGS Optimizer and checkpoint
    xOpt = oechem.OEDoubleArray(1)
    optimizer = oeff.OEBFGSOpt()
    value = optimizer(func, ChkPt(), x, xOpt)
    oechem.OEThrow.Info("Function has a minimia at x = %d and the minimum value is %d"
                        % (xOpt[0], value))

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Utility to load a previously generated MMP index
#  and use the transformations discovered to alter a second set of structures
# ---------------------------------------------------------------------------
# MatchedPairTransform.py mmp_index input_mols output_mols
#
# mmp_index: filename of matched pair index
# input_mols: filename of molecules to transform based on analysis
# output_mols: filename to collect transformed molecules
#############################################################################
from openeye import oechem
from openeye import oemedchem
import sys


def MMPTransform(itf):
    # input structure(s) to process
    ifsmols = oechem.oemolistream()
    if not ifsmols.open(itf.GetString("-input")):
        oechem.OEThrow.Fatal("Unable to open %s for reading" %
                             itf.GetString("-input"))

    # check MMP index
    mmpimport = itf.GetString("-mmpindex")
    if not oemedchem.OEIsMatchedPairAnalyzerFileType(mmpimport):
        oechem.OEThrow.Fatal('Not a valid matched pair index input file, {}'.format(mmpimport))

    # load MMP index
    mmp = oemedchem.OEMatchedPairAnalyzer()
    if not oemedchem.OEReadMatchedPairAnalyzer(mmpimport, mmp):
        oechem.OEThrow.Fatal("Unable to load index {}".format(mmpimport))

    if not mmp.NumMols():
        oechem.OEThrow.Fatal('No records in loaded MMP index file: {}'.format(mmpimport))

    if not mmp.NumMatchedPairs():
        oechem.OEThrow.Fatal('No matched pairs found in MMP index file, ' +
                             'use -fragGe,-fragLe options to extend indexing range')

    # output (transformed) structure(s)
    ofs = oechem.oemolostream()
    if not ofs.open(itf.GetString("-output")):
        oechem.OEThrow.Fatal("Unable to open %s for writing" %
                             itf.GetString("-output"))

    # request a specific context for the transform activity, here 0-bonds
    chemctxt = oemedchem.OEMatchedPairContext_Bond0
    askcontext = itf.GetString("-context")[:1]
    if askcontext == '0':
        chemctxt = oemedchem.OEMatchedPairContext_Bond0
    elif askcontext == '1':
        chemctxt = oemedchem.OEMatchedPairContext_Bond1
    elif askcontext == '2':
        chemctxt = oemedchem.OEMatchedPairContext_Bond2
    elif askcontext == '3':
        chemctxt = oemedchem.OEMatchedPairContext_Bond3
    elif askcontext == 'a' or askcontext == 'A':
        chemctxt = oemedchem.OEMatchedPairContext_AllBonds
    else:
        oechem.OEThrow.Fatal("Invalid context specified: " +
                             askcontext + ", only 0|1|2|3|A allowed")

    verbose = itf.GetBool("-verbose")

    # return some status information
    if verbose:
        oechem.OEThrow.Info("{}: molecules: {:d}, matched pairs: {:,d}"
                            .format(mmpimport,
                                    mmp.NumMols(),
                                    mmp.NumMatchedPairs()))

    minpairs = itf.GetInt("-minpairs")
    if minpairs > 1 and verbose:
        oechem.OEThrow.Info('Requiring at least %d matched pairs to apply transformations'
                            % minpairs)

    errs = None
    if itf.GetBool("-nowarnings"):
        errs = oechem.oeosstream()
        oechem.OEThrow.SetOutputStream(errs)

    orec = 0
    ocnt = 0
    for mol in ifsmols.GetOEGraphMols():
        orec += 1
        iter = oemedchem.OEMatchedPairApplyTransforms(mol, mmp, chemctxt, minpairs)
        if not iter.IsValid():
            if verbose:
                # as minpairs increases, fewer transformed mols are generated - output if requested
                name = mol.GetTitle()
                if not mol.GetTitle():
                    name = 'Record ' + str(orec)
                oechem.OEThrow.Info("%s did not produce any output" % name)
            continue
        if errs is not None:
            errs.clear()
        for outmol in iter:
            ocnt += 1
            oechem.OEWriteMolecule(ofs, outmol)
        if errs is not None:
            errs.clear()

    if not orec:
        oechem.OEThrow.Fatal('No records in input structure file to transform')

    if not ocnt:
        oechem.OEThrow.Warning('No transformed structures generated')

    print("Input molecules={} Output molecules={}".format(orec, ocnt))

    return 0


############################################################
InterfaceData = """
# matchedpairtransform interface file
!CATEGORY MatchedPairTransform

    !CATEGORY I/O
        !PARAMETER -mmpindex 1
          !TYPE string
          !REQUIRED true
          !BRIEF Input filename of serialized matched pair index to load
        !END

        !PARAMETER -input 2
          !ALIAS -i
          !ALIAS -in
          !TYPE string
          !REQUIRED true
          !BRIEF Input filename of structures to process using matched pairs from -mmpindex
        !END

        !PARAMETER -output 3
          !ALIAS -o
          !ALIAS -out
          !TYPE string
          !REQUIRED true
          !BRIEF Output filename
        !END
    !END

    !CATEGORY options
        !PARAMETER -context 1
           !ALIAS -c
           !TYPE string
           !DEFAULT 0
           !BRIEF chemistry context to use for the transformation [0|1|2|3|A]
        !END

        !PARAMETER -minpairs 2
           !TYPE int
           !DEFAULT 0
           !BRIEF require at least -minpairs to apply the transformations (default: all)
        !END

        !PARAMETER -verbose 3
           !TYPE bool
           !DEFAULT 0
           !BRIEF generate verbose output
        !END

        !PARAMETER -nowarnings 4
           !TYPE bool
           !DEFAULT 1
           !BRIEF suppress warning messages from applying transformations
        !END
    !END
!END
"""


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData)
    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    MMPTransform(itf)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oedepict
from openeye import oegrapheme

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE GRAPHEME DOCUMENTATION
###############################################################


def ImportMolecule(filename):

    ifs = oechem.oemolistream()
    if not ifs.open(filename):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % filename)

    mol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(ifs, mol):
        oechem.OEThrow.Fatal("Unable to read molecule in %s" % filename)

    return mol


if len(sys.argv) != 3:
    oechem.OEThrow.Usage("%s <receptor> <ligand>" % sys.argv[0])

receptor = ImportMolecule(sys.argv[1])
ligand = ImportMolecule(sys.argv[2])

asite = oechem.OEInteractionHintContainer(receptor, ligand)
oechem.OEPerceiveInteractionHints(asite)
oegrapheme.OEPrepareActiveSiteDepiction(asite)

# @ <SNIPPET-OERENDERACTIVESITE-IMAGE-ADISP>
# initializing asite oechem.OEInteractionHintContainer(receptor, ligand) object

image = oedepict.OEImage(800.0, 600.0)
opts = oegrapheme.OE2DActiveSiteDisplayOptions(image.GetWidth(), image.GetHeight())
opts.SetRenderInteractiveLegend(True)
adisp = oegrapheme.OE2DActiveSiteDisplay(asite, opts)

oegrapheme.OERenderActiveSite(image, adisp)
oedepict.OEWriteImage("OERenderActiveSite-image-adisp.svg", image)
# @ </SNIPPET-OERENDERACTIVESITE-IMAGE-ADISP>
oedepict.OEWriteImage("OERenderActiveSite-image-adisp.pdf", image)



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oegraphsim


# @ <SNIPPET-ATOMTYPING>
def PrintTanimoto(molA, molB, atype, btype):
    fpA = oegraphsim.OEFingerPrint()
    fpB = oegraphsim.OEFingerPrint()
    numbits = 2048
    minb = 0
    maxb = 5
    oegraphsim.OEMakePathFP(fpA, molA, numbits, minb, maxb, atype, btype)
    oegraphsim.OEMakePathFP(fpB, molB, numbits, minb, maxb, atype, btype)
    print("Tanimoto(A,B) = %.3f" % oegraphsim.OETanimoto(fpA, fpB))


molA = oechem.OEGraphMol()
oechem.OESmilesToMol(molA, "Oc1c2c(cc(c1)CF)CCCC2")
molB = oechem.OEGraphMol()
oechem.OESmilesToMol(molB, "c1ccc2c(c1)c(cc(n2)CCl)N")

PrintTanimoto(molA, molB, oegraphsim.OEFPAtomType_DefaultAtom, oegraphsim.OEFPBondType_DefaultBond)
PrintTanimoto(molA, molB, oegraphsim.OEFPAtomType_DefaultAtom | oegraphsim.OEFPAtomType_EqAromatic,
              oegraphsim.OEFPBondType_DefaultBond)
PrintTanimoto(molA, molB, oegraphsim.OEFPAtomType_Aromaticity, oegraphsim.OEFPBondType_DefaultBond)
PrintTanimoto(molA, molB, oegraphsim.OEFPAtomType_InRing, oegraphsim.OEFPBondType_InRing)
# @ </SNIPPET-ATOMTYPING>



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem


def main(argv=[__name__]):
    kernel = oechem.OESquareMatrix(4)
    kernel.SetRowData(0, [2686.9, 549.35, 509.31, 456.37])
    kernel.SetRowData(1, [549.12, 2815.15, 2433.03, 496.09])
    kernel.SetRowData(2, [509.11, 2432.17, 2804.49, 356.28])
    kernel.SetRowData(3, [456.36, 496.24, 356.27, 3643.08])
    response = [4.25, 6.62, 5.28, 8.10]

    pls = oechem.OEKernelPLS()
    pls.Fit(kernel, response, 1);
    pred_value = pls.Predict([2686.9, 549.35, 509.31, 456.37]);
    print("Actual: ", 4.25, " predicted: ", pred_value)
    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oeff

# ///////////////////////////////////////////////////////////////////////////
# The following function is a contrived example to show how to             //
# write a user-defined function.  The energy function is the square        //
# of the distance from the origin.  The derivative then is two times the   //
# coordinate component.  The function will attempt to place all atoms of   //
# a molecule at the origin.                                                //
# ///////////////////////////////////////////////////////////////////////////


class Harmonic(oeff.OEMolFunc1):
    def __init__(self):
        oeff.OEMolFunc1.__init__(self)
        self.natoms = 0
        pass

    def begin(self):
        pass

    def NumVar(self):
        return 3*self.natoms

    def Setup(self, mol):
        self.natoms = mol.GetMaxAtomIdx()
        return True

    def __call__(self, coord, grad=None):
        energy = 0.0
        if isinstance(coord, oechem.OEDoubleArray):
            if grad is not None:
                for i in range(0, self.natoms):
                    grad[3*i] += 2.0 * coord[3*i]  # x gradient
                    grad[3*i+1] += 2.0 * coord[3*i+1]  # y gradient
                    grad[3*i+2] += 2.0 * coord[3*i+2]  # z gradient
                    energy += coord[3*i] * coord[3*i]  # x distance from zero
                    energy += coord[3*i+1] * coord[3*i+1]  # y distance from zero
                    energy += coord[3*i+2] * coord[3*i+2]  # z distance from zero
            else:
                for i in range(0, self.natoms):
                    energy += coord[3*i] * coord[3*i]  # x distance from zero
                    energy += coord[3*i+1] * coord[3*i+1]  # y distance from zero
                    energy += coord[3*i+2] * coord[3*i+2]  # z distance from zero
        else:
            coord1 = oechem.OEDoubleArray(coord, self.NumVar(), False)
            if grad is not None:
                grad1 = oechem.OEDoubleArray(grad, self.NumVar(), False)
                for i in range(0, self.natoms):
                    grad1[3*i] += 2.0 * coord1[3*i]  # x gradient
                    grad1[3*i+1] += 2.0 * coord1[3*i+1]  # y gradient
                    grad1[3*i+2] += 2.0 * coord1[3*i+2]  # z gradient
                    energy += coord1[3*i] * coord1[3*i]  # x distance from zero
                    energy += coord1[3*i+1] * coord1[3*i+1]  # y distance from zero
                    energy += coord1[3*i+2] * coord1[3*i+2]  # z distance from zero
            else:
                for i in range(0, self.natoms):
                    energy += coord1[3*i] * coord1[3*i]  # x distance from zero
                    energy += coord1[3*i+1] * coord1[3*i+1]  # y distance from zero
                    energy += coord1[3*i+2] * coord1[3*i+2]  # z distance from zero
        return energy


def main(args):
    if len(args) != 2:
        oechem.OEThrow.Usage("%s <input>" % args[0])

    ifs = oechem.oemolistream()
    if not ifs.open(args[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % args[1])

    mol = oechem.OEGraphMol()
    oechem.OEReadMolecule(ifs, mol)
    vecCoords = oechem.OEDoubleArray(3*mol.GetMaxAtomIdx())
    mol.GetCoords(vecCoords)

    hermonic = Harmonic()
    hermonic.Setup(mol)
    optimizer = oeff.OEBFGSOpt()
    energy = optimizer(hermonic, vecCoords, vecCoords)
    oechem.OEThrow.Info("Optimized energy: %d" % energy)

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



# CONFIDENTIAL. (C) 2022 Cadence Design Systems, Inc. (Cadence)
# All rights reserved.
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO CADENCE
# AND IS SUBJECT TO THE FULL PROTECTION OF COPYRIGHT AND TRADE SECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from Cadence is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact Cadence at eyesopen.com/legal if you have any questions
# about this warning.


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")


def swig_import_helper():
    from os.path import dirname
    import importlib.util
    import importlib.abc

    spec = importlib.machinery.PathFinder().find_spec("_oechem", [dirname(__file__)])

    if spec is None:
        # OpenEye Import Statements
        spec = importlib.machinery.PathFinder().find_spec("libs",[dirname(__file__)])
    libs = importlib.util.module_from_spec(spec)

    import sys
    sys.modules[spec.name] = libs
    spec.loader.exec_module(libs)

    assert not sys.platform.startswith('win')

    _oeiupac = libs.OEGetModule('_oeiupac2811')
    return _oeiupac

_oeiupac = swig_import_helper()
del swig_import_helper

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import weakref


def __no_op(*args) -> "void":
    return _oeiupac.__no_op(*args)
import openeye.oechem as oechem
OENamStyle_NS_VERSION = _oeiupac.OENamStyle_NS_VERSION

OENamStyle_NS_COMMON = _oeiupac.OENamStyle_NS_COMMON

OENamStyle_NS_CAS = _oeiupac.OENamStyle_NS_CAS

OENamStyle_NS_OLD = _oeiupac.OENamStyle_NS_OLD

OENamStyle_NS_SYS = _oeiupac.OENamStyle_NS_SYS

OENamStyle_NS_ESTER = _oeiupac.OENamStyle_NS_ESTER

OENamStyle_NS_STEREO = _oeiupac.OENamStyle_NS_STEREO

OENamStyle_NS_DASH = _oeiupac.OENamStyle_NS_DASH

OENamStyle_NS_AMINE = _oeiupac.OENamStyle_NS_AMINE

OENamStyle_NS_RINGLOC = _oeiupac.OENamStyle_NS_RINGLOC

OENamStyle_NS_PERMIDX = _oeiupac.OENamStyle_NS_PERMIDX

OENamStyle_NS_IUPAC79 = _oeiupac.OENamStyle_NS_IUPAC79

OENamStyle_NS_IUPAC93 = _oeiupac.OENamStyle_NS_IUPAC93

OENamStyle_NS_AUTONOM = _oeiupac.OENamStyle_NS_AUTONOM

OENamStyle_NS_PSEUDOHAL = _oeiupac.OENamStyle_NS_PSEUDOHAL

OENamStyle_NS_ACDNAME = _oeiupac.OENamStyle_NS_ACDNAME

OENamStyle_NS_AMMONIO = _oeiupac.OENamStyle_NS_AMMONIO

OENamStyle_NS_PERMIDX2 = _oeiupac.OENamStyle_NS_PERMIDX2

OENamStyle_NS_1NLOC = _oeiupac.OENamStyle_NS_1NLOC

OENamStyle_NS_FLIPENH = _oeiupac.OENamStyle_NS_FLIPENH

OENamStyle_NS_MAX = _oeiupac.OENamStyle_NS_MAX

OECharSet_DEFAULT = _oeiupac.OECharSet_DEFAULT

OECharSet_ASCII = _oeiupac.OECharSet_ASCII

OECharSet_HTML = _oeiupac.OECharSet_HTML

OECharSet_UTF8 = _oeiupac.OECharSet_UTF8

OECharSet_SJIS = _oeiupac.OECharSet_SJIS

OECharSet_EUCJP = _oeiupac.OECharSet_EUCJP

OECharSet_Latin1 = _oeiupac.OECharSet_Latin1

OELanguage_ENGLISH = _oeiupac.OELanguage_ENGLISH

OELanguage_AMERICAN = _oeiupac.OELanguage_AMERICAN

OELanguage_BRITISH = _oeiupac.OELanguage_BRITISH

OELanguage_INTERNATIONAL = _oeiupac.OELanguage_INTERNATIONAL

OELanguage_CHINESE = _oeiupac.OELanguage_CHINESE

OELanguage_DANISH = _oeiupac.OELanguage_DANISH

OELanguage_DUTCH = _oeiupac.OELanguage_DUTCH

OELanguage_FRENCH = _oeiupac.OELanguage_FRENCH

OELanguage_GERMAN = _oeiupac.OELanguage_GERMAN

OELanguage_GREEK = _oeiupac.OELanguage_GREEK

OELanguage_HUNGARIAN = _oeiupac.OELanguage_HUNGARIAN

OELanguage_IRISH = _oeiupac.OELanguage_IRISH

OELanguage_ITALIAN = _oeiupac.OELanguage_ITALIAN

OELanguage_JAPANESE = _oeiupac.OELanguage_JAPANESE

OELanguage_POLISH = _oeiupac.OELanguage_POLISH

OELanguage_PORTUGUESE = _oeiupac.OELanguage_PORTUGUESE

OELanguage_ROMANIAN = _oeiupac.OELanguage_ROMANIAN

OELanguage_RUSSIAN = _oeiupac.OELanguage_RUSSIAN

OELanguage_SLOVAK = _oeiupac.OELanguage_SLOVAK

OELanguage_SPANISH = _oeiupac.OELanguage_SPANISH

OELanguage_SWEDISH = _oeiupac.OELanguage_SWEDISH

OELanguage_WELSH = _oeiupac.OELanguage_WELSH


def OENameLocant(loc: "unsigned int", iupac: "bool"=False) -> "std::string":
    r"""OENameLocant(unsigned int loc, bool iupac=False) -> std::string"""
    return _oeiupac.OENameLocant(loc, iupac)

def OEParseIUPACName(mol: "OEMolBase", name: "char const *") -> "bool":
    r"""OEParseIUPACName(OEMolBase mol, char const * name) -> bool"""
    return _oeiupac.OEParseIUPACName(mol, name)

def OECreateIUPACName(*args) -> "std::string":
    r"""OECreateIUPACName(OEMolBase mol, unsigned char const * style=OENamStyleOpenEye) -> std::string"""
    return _oeiupac.OECreateIUPACName(*args)

def OEGetIUPACNamStyle(style: "std::string const &") -> "unsigned char const *":
    r"""OEGetIUPACNamStyle(std::string const & style) -> unsigned char const *"""
    return _oeiupac.OEGetIUPACNamStyle(style)

def OEGetCIPStereo(*args) -> "char":
    r"""
    OEGetCIPStereo(OEMolBase mol, OEAtomBase atm) -> char
    OEGetCIPStereo(OEMolBase mol, OEBondBase bnd) -> char
    """
    return _oeiupac.OEGetCIPStereo(*args)

def OESetCIPStereo(*args) -> "bool":
    r"""
    OESetCIPStereo(OEMolBase mol, OEAtomBase atm, char s) -> bool
    OESetCIPStereo(OEMolBase mol, OEBondBase bnd, char s) -> bool
    """
    return _oeiupac.OESetCIPStereo(*args)

def OECapitalizeName(ptr: "char const *") -> "std::string":
    r"""OECapitalizeName(char const * ptr) -> std::string"""
    return _oeiupac.OECapitalizeName(ptr)

def OELowerCaseName(ptr: "char const *") -> "std::string":
    r"""OELowerCaseName(char const * ptr) -> std::string"""
    return _oeiupac.OELowerCaseName(ptr)

def OEReorderIndexName(ptr: "char const *") -> "std::string":
    r"""OEReorderIndexName(char const * ptr) -> std::string"""
    return _oeiupac.OEReorderIndexName(ptr)

def OEGetIUPACLanguage(langStr: "std::string const &") -> "unsigned int":
    r"""OEGetIUPACLanguage(std::string const & langStr) -> unsigned int"""
    return _oeiupac.OEGetIUPACLanguage(langStr)

def OEFromLanguage(ptr: "char const *", lang: "unsigned int") -> "std::string":
    r"""OEFromLanguage(char const * ptr, unsigned int lang) -> std::string"""
    return _oeiupac.OEFromLanguage(ptr, lang)

def OEToLanguage(ptr: "char const *", lang: "unsigned int") -> "std::string":
    r"""OEToLanguage(char const * ptr, unsigned int lang) -> std::string"""
    return _oeiupac.OEToLanguage(ptr, lang)

def OEToBritish(ptr: "char const *", sulph: "bool") -> "std::string":
    r"""OEToBritish(char const * ptr, bool sulph) -> std::string"""
    return _oeiupac.OEToBritish(ptr, sulph)

def OEToChinese(ptr: "char const *") -> "std::string":
    r"""OEToChinese(char const * ptr) -> std::string"""
    return _oeiupac.OEToChinese(ptr)

def OEToDanish(ptr: "char const *") -> "std::string":
    r"""OEToDanish(char const * ptr) -> std::string"""
    return _oeiupac.OEToDanish(ptr)

def OEToDutch(ptr: "char const *") -> "std::string":
    r"""OEToDutch(char const * ptr) -> std::string"""
    return _oeiupac.OEToDutch(ptr)

def OEToFrench(ptr: "char const *") -> "std::string":
    r"""OEToFrench(char const * ptr) -> std::string"""
    return _oeiupac.OEToFrench(ptr)

def OEToGerman(ptr: "char const *") -> "std::string":
    r"""OEToGerman(char const * ptr) -> std::string"""
    return _oeiupac.OEToGerman(ptr)

def OEToGreek(ptr: "char const *") -> "std::string":
    r"""OEToGreek(char const * ptr) -> std::string"""
    return _oeiupac.OEToGreek(ptr)

def OEToHungarian(ptr: "char const *") -> "std::string":
    r"""OEToHungarian(char const * ptr) -> std::string"""
    return _oeiupac.OEToHungarian(ptr)

def OEToIrish(ptr: "char const *") -> "std::string":
    r"""OEToIrish(char const * ptr) -> std::string"""
    return _oeiupac.OEToIrish(ptr)

def OEToItalian(ptr: "char const *") -> "std::string":
    r"""OEToItalian(char const * ptr) -> std::string"""
    return _oeiupac.OEToItalian(ptr)

def OEToJapanese(ptr: "char const *") -> "std::string":
    r"""OEToJapanese(char const * ptr) -> std::string"""
    return _oeiupac.OEToJapanese(ptr)

def OEToPolish(ptr: "char const *") -> "std::string":
    r"""OEToPolish(char const * ptr) -> std::string"""
    return _oeiupac.OEToPolish(ptr)

def OEToPortuguese(ptr: "char const *") -> "std::string":
    r"""OEToPortuguese(char const * ptr) -> std::string"""
    return _oeiupac.OEToPortuguese(ptr)

def OEToRomanian(ptr: "char const *") -> "std::string":
    r"""OEToRomanian(char const * ptr) -> std::string"""
    return _oeiupac.OEToRomanian(ptr)

def OEToRussian(ptr: "char const *") -> "std::string":
    r"""OEToRussian(char const * ptr) -> std::string"""
    return _oeiupac.OEToRussian(ptr)

def OEToSlovak(ptr: "char const *") -> "std::string":
    r"""OEToSlovak(char const * ptr) -> std::string"""
    return _oeiupac.OEToSlovak(ptr)

def OEToSpanish(ptr: "char const *") -> "std::string":
    r"""OEToSpanish(char const * ptr) -> std::string"""
    return _oeiupac.OEToSpanish(ptr)

def OEToSwedish(ptr: "char const *") -> "std::string":
    r"""OEToSwedish(char const * ptr) -> std::string"""
    return _oeiupac.OEToSwedish(ptr)

def OEToWelsh(ptr: "char const *") -> "std::string":
    r"""OEToWelsh(char const * ptr) -> std::string"""
    return _oeiupac.OEToWelsh(ptr)

def OEFromBritish(ptr: "char const *") -> "std::string":
    r"""OEFromBritish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromBritish(ptr)

def OEFromChinese(ptr: "char const *") -> "std::string":
    r"""OEFromChinese(char const * ptr) -> std::string"""
    return _oeiupac.OEFromChinese(ptr)

def OEFromDanish(ptr: "char const *") -> "std::string":
    r"""OEFromDanish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromDanish(ptr)

def OEFromDutch(ptr: "char const *") -> "std::string":
    r"""OEFromDutch(char const * ptr) -> std::string"""
    return _oeiupac.OEFromDutch(ptr)

def OEFromFrench(ptr: "char const *") -> "std::string":
    r"""OEFromFrench(char const * ptr) -> std::string"""
    return _oeiupac.OEFromFrench(ptr)

def OEFromGerman(ptr: "char const *") -> "std::string":
    r"""OEFromGerman(char const * ptr) -> std::string"""
    return _oeiupac.OEFromGerman(ptr)

def OEFromGreek(ptr: "char const *") -> "std::string":
    r"""OEFromGreek(char const * ptr) -> std::string"""
    return _oeiupac.OEFromGreek(ptr)

def OEFromHungarian(ptr: "char const *") -> "std::string":
    r"""OEFromHungarian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromHungarian(ptr)

def OEFromIrish(ptr: "char const *") -> "std::string":
    r"""OEFromIrish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromIrish(ptr)

def OEFromItalian(ptr: "char const *") -> "std::string":
    r"""OEFromItalian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromItalian(ptr)

def OEFromJapanese(ptr: "char const *") -> "std::string":
    r"""OEFromJapanese(char const * ptr) -> std::string"""
    return _oeiupac.OEFromJapanese(ptr)

def OEFromPolish(ptr: "char const *") -> "std::string":
    r"""OEFromPolish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromPolish(ptr)

def OEFromPortuguese(ptr: "char const *") -> "std::string":
    r"""OEFromPortuguese(char const * ptr) -> std::string"""
    return _oeiupac.OEFromPortuguese(ptr)

def OEFromRomanian(ptr: "char const *") -> "std::string":
    r"""OEFromRomanian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromRomanian(ptr)

def OEFromRussian(ptr: "char const *") -> "std::string":
    r"""OEFromRussian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromRussian(ptr)

def OEFromSlovak(ptr: "char const *") -> "std::string":
    r"""OEFromSlovak(char const * ptr) -> std::string"""
    return _oeiupac.OEFromSlovak(ptr)

def OEFromSpanish(ptr: "char const *") -> "std::string":
    r"""OEFromSpanish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromSpanish(ptr)

def OEFromSwedish(ptr: "char const *") -> "std::string":
    r"""OEFromSwedish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromSwedish(ptr)

def OEFromWelsh(ptr: "char const *") -> "std::string":
    r"""OEFromWelsh(char const * ptr) -> std::string"""
    return _oeiupac.OEFromWelsh(ptr)

def OEGetIUPACCharSet(charset: "std::string const &") -> "unsigned int":
    r"""OEGetIUPACCharSet(std::string const & charset) -> unsigned int"""
    return _oeiupac.OEGetIUPACCharSet(charset)

def OEToASCII(ptr: "char const *", remove_markup: "bool const"=True) -> "std::string":
    r"""OEToASCII(char const * ptr, bool const remove_markup=True) -> std::string"""
    return _oeiupac.OEToASCII(ptr, remove_markup)

def OEToUTF8(ptr: "char const *", remove_markup: "bool const"=True) -> "std::string":
    r"""OEToUTF8(char const * ptr, bool const remove_markup=True) -> std::string"""
    return _oeiupac.OEToUTF8(ptr, remove_markup)

def OEFromUTF8(ptr: "char const *") -> "std::string":
    r"""OEFromUTF8(char const * ptr) -> std::string"""
    return _oeiupac.OEFromUTF8(ptr)

def OEToHTML(ptr: "char const *") -> "std::string":
    r"""OEToHTML(char const * ptr) -> std::string"""
    return _oeiupac.OEToHTML(ptr)

def OEFromHTML(ptr: "char const *") -> "std::string":
    r"""OEFromHTML(char const * ptr) -> std::string"""
    return _oeiupac.OEFromHTML(ptr)

def OEToSJIS(ptr: "char const *") -> "std::string":
    r"""OEToSJIS(char const * ptr) -> std::string"""
    return _oeiupac.OEToSJIS(ptr)

def OEToEUCJP(ptr: "char const *") -> "std::string":
    r"""OEToEUCJP(char const * ptr) -> std::string"""
    return _oeiupac.OEToEUCJP(ptr)

def OEFromKOI8R(ptr: "char const *") -> "std::string":
    r"""OEFromKOI8R(char const * ptr) -> std::string"""
    return _oeiupac.OEFromKOI8R(ptr)
OE_OEIUPAC_VERSION = _oeiupac.OE_OEIUPAC_VERSION


def OEIUPACGetRelease() -> "char const *":
    r"""OEIUPACGetRelease() -> char const *"""
    return _oeiupac.OEIUPACGetRelease()

def OEIUPACGetVersion() -> "unsigned int":
    r"""OEIUPACGetVersion() -> unsigned int"""
    return _oeiupac.OEIUPACGetVersion()

def OEIUPACGetArch() -> "char const *":
    r"""OEIUPACGetArch() -> char const *"""
    return _oeiupac.OEIUPACGetArch()

def OEIUPACGetPlatform() -> "char const *":
    r"""OEIUPACGetPlatform() -> char const *"""
    return _oeiupac.OEIUPACGetPlatform()

def OEIUPACIsLicensed(feature: "char const *"=None, expdate: "unsigned int *"=None) -> "bool":
    r"""OEIUPACIsLicensed(char const * feature=None, unsigned int * expdate=None) -> bool"""
    return _oeiupac.OEIUPACIsLicensed(feature, expdate)

def OEIUPACGetLicensee(*args) -> "std::string":
    r"""
    OEIUPACGetLicensee(std::string & licensee) -> bool
    OEIUPACGetLicensee() -> std::string
    """
    return _oeiupac.OEIUPACGetLicensee(*args)

def OEIUPACGetSite(*args) -> "std::string":
    r"""
    OEIUPACGetSite(std::string & site) -> bool
    OEIUPACGetSite() -> std::string
    """
    return _oeiupac.OEIUPACGetSite(*args)

cvar = _oeiupac.cvar
OENamStyleOpenEye = cvar.OENamStyleOpenEye
OENamStyleTraditional = cvar.OENamStyleTraditional
OENamStyleSystematic = cvar.OENamStyleSystematic
OENamStyleIUPAC = cvar.OENamStyleIUPAC
OENamStyleCAS = cvar.OENamStyleCAS
OENamStyleCASIndex = cvar.OENamStyleCASIndex
OENamStyleAutoNom = cvar.OENamStyleAutoNom
OENamStyleIUPAC79 = cvar.OENamStyleIUPAC79
OENamStyleIUPAC93 = cvar.OENamStyleIUPAC93
OENamStyleACDName = cvar.OENamStyleACDName




#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Converts a ring dictionary into a multi-page PDF document.
#############################################################################

import sys
from openeye import oechem
from openeye import oedepict


def main(argv=[__name__]):

    itf = oechem.OEInterface(InterfaceData)
    oedepict.OEConfigureReportOptions(itf)

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    ifname = itf.GetString("-ringdict")
    ofname = itf.GetString("-out")

    if not oechem.OEIsValid2DRingDictionary(ifname):
        oechem.OEThrow.Fatal("Invalid ring dictionary file!")

    ringdict = oechem.OE2DRingDictionary(ifname)

    ropts = oedepict.OEReportOptions()
    oedepict.OESetupReportOptions(ropts, itf)

    oedepict.OEWrite2DRingDictionaryReport(ofname, ringdict, ropts)

    return 0


#############################################################################
# INTERFACE
#############################################################################

InterfaceData = """
!BRIEF [-ringdict] <input ringdict> [-out] <output pdf>

!CATEGORY "input/output options :"

    !PARAMETER -ringdict
      !ALIAS -rd
      !TYPE string
      !REQUIRED true
      !KEYLESS 1
      !VISIBILITY simple
      !BRIEF Input ring dictionary filename
      !DETAIL
        2D ring dictionaries can be generated by the following OEChem examples:
        C++    - createringdict.cpp
        Python - createringdict.py
        Java   - CreateRingDict.java
        C#     - CreateRingDict.cs
    !END

    !PARAMETER -out
      !ALIAS -o
      !TYPE string
      !REQUIRED true
      !KEYLESS 2
      !VISIBILITY simple
      !BRIEF Output filename
    !END

!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
import sys
from openeye import oechem


# @ <SNIPPET-IS-SAME-RESIDUE-PRED>
class IsSameResidue(oechem.OEUnaryAtomPred):
    def __init__(self, res):
        oechem.OEUnaryAtomPred.__init__(self)
        self.referenceResidue = res

    def __call__(self, atom):
        res = oechem.OEAtomGetResidue(atom)
        return oechem.OESameResidue(res, self.referenceResidue)

    def CreateCopy(self):
        # __disown__ is required to allow C++ to take ownership of this
        # object and its memory
        return IsSameResidue(self.referenceResidue).__disown__()
# @ </SNIPPET-IS-SAME-RESIDUE-PRED>


def main(argv=[__name__]):

    itf = oechem.OEInterface(InterfaceData)

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    ims = oechem.oemolistream()
    ims.SetFlavor(oechem.OEFormat_PDB, oechem.OEIFlavor_PDB_ALTLOC)

    inputFile = itf.GetString("-in")
    if not ims.open(inputFile):
        oechem.OEThrow.Fatal("Unable to open %s for reading." % inputFile)

    if not oechem.OEIs3DFormat(ims.GetFormat()):
        oechem.OEThrow.Fatal("%s is not in a 3D format." % inputFile)

    mol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(ims, mol):
        oechem.OEThrow.Fatal("Unable to read %s." % inputFile)

    if not oechem.OEHasResidues(mol):
        oechem.OEPerceiveResidues(mol, oechem.OEPreserveResInfo_All)

    alf = oechem.OEAltLocationFactory(mol)
    if alf.GetGroupCount() != 0:
        alf.MakePrimaryAltMol(mol)

    # in our example, we will select the first histidine
    selectedResidue = oechem.OEResidue()
    for atom in mol.GetAtoms():
        res = oechem.OEAtomGetResidue(atom)
        if oechem.OEGetResidueIndex(res) == oechem.OEResidueIndex_HIS:
            selectedResidue = res
            break

    # @ <SNIPPET-PLACE-HYDROGENS-PRED>
    # given predicate IsSameResidue, residue selectedResidue and molecule mol...
    opt = oechem.OEPlaceHydrogensOptions()
    opt.SetNoFlipPredicate(IsSameResidue(selectedResidue))

    if oechem.OEPlaceHydrogens(mol, opt):
        # selectedResidue will not be flipped...
        # @ </SNIPPET-PLACE-HYDROGENS-PRED>
        print("success")

    ims.close()


#############################################################################
# INTERFACE
#############################################################################

InterfaceData = '''
!BRIEF PlaceHydrogensPredDoc.py <inmol>

!CATEGORY "input options :"
   !PARAMETER -in
      !ALIAS -i
      !TYPE string
      !BRIEF Input molecule filename (must have 3D coordinates)
      !SIMPLE true
      !REQUIRED true
      !KEYLESS 1
   !END
!END
'''

if __name__ == "__main__":
    sys.exit(main(sys.argv))
# @ </SNIPPET>
